
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python Fintech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x020\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xd2)\x00\x00PYARMOR\x00\x00\x03\t\x00a\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x92)\x00\x00\x00\x00\x00\x00t \xe3v)\xcc\x95=\xf8)H\xcc\xe6(\xca\x17\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2a0\x8e\xc4\xaa?\x15\xe2\xa1\xed+\xcbKb#`\x16\x95\xbe\x16\xc8\xc0\xa0\x16v\xdb\x99B\xae\x1f.w\xeaG"h8\x96kr\x91\x0c0\xabA\x80?\xcc\xfb`\xf2\x19\xb8'
        b">\x806\xbc\xbaF\xac\xe4f\x84\xdb\xfc\x04\xb7Y\xe5\x9d\xa1D\x02ax\xc7\x0e\xbf7E0l\x99\x00Y|\xc2<\x05W\xa7\x91UD\xd3\xc17\xbaEjd\x94\xd9R\xf1\xbd`\xbc\xc4|\x92'VfG\xf3,"
        b"(q[}\xc4\xb4\xf2\xfc?\xe1\x89\xf2\x0b\x05b\x85\xcc\x9a_{\x98\xb5u\x93\xb8\xb9\x87\xb9)\x03U\x1e\xf1`\xb2%D\xb5\x85|_\xcc'4\x9b\x9a\xa6\x1e\xeb\xf8;\x8e\x1bNWEq\x16\xabL\xaa\xd1\x07}"
        b'^\x86\xf9w\xc2\x06\xc9\x87s\x1c~\x9e\xd0\x1c\xf1W\xff\xfb\x17h\xd8\\\xbb\xa9\x8dJJi\xd7J\x86\xdfe2\xb6\x17i\x86\xd1z0u^5\xc1\xef\x02Tr\xfc\xdf\xc0J\x98\x05_\xf2eHZ\xe1\xd6\xde\x8e'
        b'{\x0c_\x1ec\xc2\x87?\xfaY\xa0x&\xd3\xf3\x83B>/?\r\x10\x18\xd0+\xba\xc2\xf0\x00O\x8c\xf4\xf4\x1cX\x94\x94O\x1fn\x1dS\x92\x86\x1e\xae\xc6\xf8\xd3\xb1\xf2\xdf?\x82\xae\x9b^\xd2t\x18\xef[\xbeG'
        b'+\xaa\xb8\x0b\x96K\x82;\xfff\x9eM\xfb\xc2\xef\t\xc3\x90\x07l\xa8\xd4\x81\x15\x88y\xcb\xaeC\xe2\x00\x04\xe2~\t,>\xee<\xaf\xb4B}\xe5\xe0\x8f\xe0\xcdcZ\xb6\x8d\xfa\x86\x95\x8d\r\x9f\x8c\xeaev\xe6\x87'
        b'\xf9<n\xf8\x88\xb0\xe6\xf9\x95\xbbh\x18`\xbe\xe9\x0f\x00>g;\x89N\x81b\xfe\x86\x8c<\x82\x91\x7fl\xf9"F\x82\x1b5\xfer\x80:\xf7:\x9d9\xbe\r;z\x84\xaf\xdc\x94\x1ey#K\x19\xb8\xf1\xb8\xfeF'
        b'\xeb\xc7v\xe9\xf3\x17C\xad"U\x8e\xd7\x99\xdc\x06\xcc\xda\xd8\xb9\xa8tH\x9f\x11\xf5x>\x12*\xf3\xcb\xf3\x05Nw\xa9\xda\xf0#\xd9^J\xe0z\xd0\x1e2M8=\x0e\x84\rDS\xf5\xdc\xd5\x8b\xefa\x8d\xd3['
        b'\xcc)\xbcIy\x0c\xbf\xbcy\x18\xcb3*\x86\xe0\x0e\x8a\xd0\x94\xd6k?\xda\xfa\xa6\xe1!tW\x87\x10\xec\x01;\x0fZ\x9d\xa4\x12\xa5tm\x19\xb2\xd62{N\xe9\xf2\x9b\xd4\xd2\xc4f\xfe\xd5\xa9}\xde\xd3\xf6\x97O'
        b'\x93\xdd&\xf4\xed\x014\x7f\x15u<\xe0J\x9b\x07\x88g4\x1f\xb7s\xb1\xcd\xc7\xcf\x96\xd3\x0fM\xfe\\\x91\xf8T3\x05\x1f2-ol\xe1\x9b\xe6\xcd\xf1\x12\x8et\xbb\x92% `z8\xd0\xd6-\xccw\x0c\x8fX'
        b'\x8alX\xf9v\x0f\xc2\x01vf\xe4\x02\xff\xac\xa9\xac`\x07\x07\xe4@\x7f \x02\xc1\xe9\xd1-\xe9O\x82\x9b)\xdd\x9c\xd7r\xd1\x03\xe70\x12W?|<\x90W\x11\xbbG?\\YX\xd8\x9b\x0c|\xe5\x05\xa6\x06Z'
        b'\x9f.\x9fl2\xbf\x16\xf5\xc4\x15\xd3B\x08\x05U\xe6\xf5\xf3\x84\xccl\xa4\x9e\x97W\x92$\xb6\xd1j\xc91\xffA+;\xfaT\x03\xdb\xe0\x014BL&\x93\xf3\xbb\x84|\x00@\x14\xaca\xe0\x17vo\x98\xa7\xb5*'
        b']\xd0o\xd8|\xe4H\xc0\x1b\xc6~\xbf\x8f\xd5T\x86\xa5\x16\xf1\x0fD\x83k\xecb\x97\xb1\x8a\xe9\xb9,=\xa2\x1a[x\xbb\xdat\xfa\x0f\x80\xf9w\x8f\x19\xfd\xd5\xd0\xa4K5g\x8f\xcem\x19\xa5?\xc0G\xef\xee&'
        b'Y\x02#\xcf<\xb1p2\x01>\xd1\x15u\x1d\xad\x8e\x08\x80\x0b6\xbb\xfb\x0f\x85[\xef\xb1A\xcb\xb1\xff\xa3\x9db\xe8\xbe\xe5~\xa1\x1b\x08M\xf6%\x1eh\xb9\x02M\\\xb4 L\xe3\x93%\xc9\x86\xd2a\xa4\x9b;\xa6'
        b'\t\x06]\x1e%[F\xf8Tn"O\x93N\xa6\x8d&*\x9e\x87\x86\x0f\x0b\xb9p\xbeBh\x8f\xcb\xc2>}\xd0\xda\xc3\x95]\xaf\xfd\xd1p\x13"\x06\x8a\xa1\x88\xc3.\xc2\xe3\xb6\xc3R\xa0\x9c\x90\xcbTT\xben~'
        b'V\x06\x1cU\x0f\xaa\xb1\xa5\x97$`\xd7kzS\x91\xf9  \xecr\\=`\x15\xb8\xf2\x1c\xe6\x11\xb3\x00\xde\xe1\x0b\xf6\x90\xa8q\x03?R\x89\xa7\xd2R$\xaf\xf7\x14\xab0f\x9b\xde8\xd3\x9a\xa4\xed\xbe\x07(\x97'
        b'\x82E\x89\x01\'\x90\x82\xa8B\x89\x14\xbe3\xc7\xb1\x18\xf0\x87u\x84\x82N-\'\x84\x17\xdd\xc8\x08\xdd\xcc\xae\xc9\xd9\x96"\xa6T\xd4\x08K\xd9\x17\x00\xe9\xde\xf6\xbb\x8f\xfc*\xa3gL\x8c<F`\xee\x83\xba\x06rO'
        b'{\xe1\xcb\x16(\xe6\r\x88\xf7\xeb\x8anL\x07\x940\x04\xa0\xc7\xfe\xde5\n\xa4+\x8b\xd0\xdb;\xcc\xca)\xb5\xbd\xd5Aw\xac]|\x06z\xca]\xeb{X\xbe\xe0\xf1\x00\xb7!h\x96wM\xbcUm\xc5\x7f=\x9c'
        b"\x18{\xe5\xe6\xf5\xfc\xb7'\xe6\xb9H\xc3G(qM\x02\x12\xa6\\([\xff\x9a\x8a\x7fN\xd6\xf1J\x10\x9d/\xcfk\x03\x1d\xdd'\x18\x9bd3\xc55\xcf~k\xc1n\x8c\xdf\x8dE3\xc5&\xad\xbf\xf6{\xef\xa7\x9e"
        b"\xab\xad\xc1\xb51\x04\x1e\x93\xba[\xe2\x0b\xa2o\xfa?\xf1\xab+\x02A\xa2\xb8\x14\xf2Y~\xa5#f'\x7f)b\xc5\x878\x92\x14\x93z\xeeY\xaaCv\xc5r\xd0\xc1w\xc17\x9a\xebEh\xc4I\xa2\xba\nw@"
        b'$\x9e\xae\xd2\xd1\x0f\xb1\xfcBS\x94\xf2p\xc6\x1f\x9e\xf8\x820\xd1K\xc1!^\xba\xb49`Rd\xb1\xf9J\x1dJ\xabT\xd9K)\xc6cr\xa8F\x18\x08f\xb2\xf2\xe8\xcf*\xbf\xfe?\xcb\x80 \xf5O\xde\x12\xa3'
        b'\xc4Ze\xd4j\x1a\x02jTp\xed\xcc\x88\x8f\xbbA\x9bW\x90\x05\x95\xe4\xa4Wc\x10*\x12Tr:\x1b\xf13\x04\xca\x948\xee\xee\x92\xa7=|Ot\x12Eh@\xc5\x978-\x83\xb3\x92\xd8YF\xf7\xb5\xf4\x96'
        b'k\x83\x8d\x83\x8av8\x06\xa4\xab\xe0\x82M-=\xfbr\xc1\xceUf\x9c\xf5\x98\x9anu\xaf\xaf\x98) \xe2\x05\x08\x0e\t\xcd\xa9cU.\xf0y;wT\xeb\xc0\xbf\\8*\x1a\xbc\xa2\x94K\x89`}\x94\xe6\xc9'
        b'6\xcd\x81\xe8Y\xf8L\x02l\x86\xd2\x1e\xac\xe7\xfe\xa5\xd3O\xe4vd\xd0\x12\xc7\xbe\xc7=\xe4\x1a\xa8\x93\r\xe8\x7f\x89\xb1\xff\xc8f\x05Dc\xea\rY\xba\xf0$\x9f\xef\x86(\xc3\'\xd6\x0e\xe0+G"\xf0\xc4\xc4D'
        b'\xc7H\xa2U\xfe(GQ$\xc2\xb5\xa8\xe7\xcf%Z8E\xe5\x93k\x98\xb6\x80\n\r\xe0v\xda\xf7\'\n\xb4\x03\x0f\r"U\xa7\xf7\x7f2v2\xbez\x1cul\x12\x8aZ"\x96H\xd2\xb8U\xd7P\xc6\xb4\x9b\xdf'
        b'\xc9\xb1\xe4\x80\xf0\x9c#MS\x15\xc2\x1f\xba\x0c\xc4\xcc\xe4v\xd3<\xd14\x9b\xdfq\xdb\x0e\xbb\xdf\xd4\xcbl\x9ce\xea\t\xf2\xbbA\xa3/\xae\x16\x11\x98\x84\x95\x13\xe1Vk\xde\xa0\xcf\xb8 2D[\x170\x10\xa8y'
        b'\xc3Oq\xd3%L\xfb2\x01+\x14\xcclu\xcb\x0fK\xcdXv)\xc0a\xd6\x84\xc8\xf6))\xdc\x81;\x94\x02\x17\xde\x82\x81\xad\xea\x1c\xce\xe3\xd0\x11\xa1\x8eTT\xca\xd1\x95WO\xed\x9a\xb9\xb5\xb1V\xad\x190<'
        b'\x15+\x16\xf1$\xb40\xd8\xa9\x03\xa1\r\xf7\x96\xee\xd2\xf3\xeb\xf8\x8e\xa0\xe2q|_\x83u\xa2n<=b0\x86\x19\xd8\x7f+\xa3\x11\xd5\x12\xe7\xd2&\x8fK\x82`E\xbd;o\xbd \xd6_\xa7\xe1Q(\xfd\xd3M'
        b'\x9e\xc2\x01x+\xb6\x01\xbe4\xf3\xbf\xdes\x0c~\xdd\xb4K\xb1\r\xf9\xb8\x1b\x9c\xde;\x05`\x0eU\xad\x08\xf6\x1a\xd4>R\xcd\x98\x98b\xcf\xa6\xed=9{\xa6DH\xde)\xca\x1f2|\x8dg\xcb\x1bn9\xda\x13'
        b'\x97R\xba\x0f\xd4b\xe5\xe4 0\xf2p&Jz_\xc7D\xb6\x1dg\xf8\x11\x16\xcdX\xea\x9dMc\xd0AA-\x0e\xc3\xaeD\x8d%hC*\x1e\xef\xba*\x1fM\xbc\xcfht\xf7\tg\n\xea\xa1\xda\xd6&\x8a\xcc'
        b"\xba\xcd\x81\xe1n\x9f\x842f\x8d3\xac\x95\xce\xa6\xe0\xf8\xcb\xd4\x9bA\r\x1e3e*D\xdc\xa2\xd96\x94a\no{h/#\x13\xac$'\xb1\x00\xfb\x1eyZ\x84\xfb(\x1e0+\x05\x1c\xb46\xfe&0\xbc\xd0"
        b"\xdf\rK\xa9\xf9\xd9\x16\xbb\x1fG\xa8\xb9f\x9c\xa53;\x06W\xb2\x86LPK\xbf\xc4R\x04\x0c\tOb\x03/'\xc9j\x9e sn#2\xa6\x9aG\xa03I\xe1m\x9fB5\x1e(\xbdg\xeb\xa3Mp\xcd="
        b'Q\xd6\x1b\xd3ko\xdf\x15/O\x98T;\xee_rrq\xbe\xd7\xafoK`B\xb5\xe1\xda.\xe5\x1c\x88\xed\xe7m\x98Ui\xbay\xc5\xdd\xad\xb20\xbf\x00\xa6\x83\xf54l\x01&\xa1\x97\xb4\x08T`\xfc\xdeP\xa2'
        b'\x0c\xec\xf7\x1b\x9e\x99\x9c\xafBcW)p\xbfs\xf1\x92\xa5l\xbb!\xad:t\x16\xd4\xd4\x9c\xe0\x97\x97\xa7\x1f\x87\x9a\x91\xfd-;\x83\x14\x9e3\xc7\xbfW2\xd4\xb1"\x13Y\xc4\x88\x8asE\x99\xb8C\x05\x92v\x92'
        b'\xf2$\x81g\n\xfc\\\xcc-U\xc9\xc7\x18=\xf9NR\xd2\xa0\xb9\xfc\xc2s6e=\xe8\x8aY\x9e%\xb5 \xb7\x1c47\xcd\x16-b\xfb\xbae#/\x9b\x0e\x8d\x8f\xf7&,\xbc\xba\xbd`\x0b\xcb\xac5|m\x94'
        b'XF\xf4\xaa\x94\x88\xbaq\xe5\x8d`t\xc3T\xba\xec\x9a\xdbV\xe8j\xa9\x061(\x94\xaa\xc1u\x14\xd0$\x9er\xc0VOnm\xbeALh\r\x05\xd3\xa1\xa9ME\x05\xbd\r\x96\x18@k\xe7\x86\x11\x03\xd7\xf6\xdc'
        b'\xc8Ph|\x128\xea\xb7\xb2\x93\xb3\x87\x8b\x0e\x17U\x82\x0ex\xce\xac\x1a\x97\xfc\xfc\x8dL\x97\xb3&_7$?1\xdb\x99\x92\x9f\xe3=\xe1\xb5\x08\xee\xee\xe0\xe1\xb6J\xe91\x01\xac\t1D\\8\xcbb\x08\xb5\xbe'
        b"\xce\xc7\xf5'\x19\x04$\xcb\t\xbd\x01]\xb9\xa0Vh\xff\x0e\xdb\xcbp\xae\x96\n\x00\x82K\xc3]\xb4\xeb/O\x08\xa6\x13&\xd1k7sv\x00Om\x90\nkG\xda\xc4\xdc\x85\tZ'\xe2\x91\x11:g]\xde\xeb"
        b'\xfe\xb1\x1d\x89\xa3c\x18\x7f\xbc\x16\x1dI\x91\x9c\xc4H \xd5\xf3J\xa3\xe9F\xfe\x8460\xbd\x8e\x8bu\xeb\x8d\xb6\xd0r\xf8\xa2\xc3\xdf\x90\xae2\xcf\x9c?f\xd2\xd5+\xe2R\xb8C\xac\xa0\xb4(\xdcj\x00vf\xf8'
        b".\x9cmaF\xea\xb6\xb8\xaa\xb1A\xba[a\x9d\x06m\xa0\xd3(\x97Z@\xa6#~\xc3\xda\x9d\xb6\x95\x92\xa4\x1a\xa6\xf0\x84K\xf0M\x06\xe8z\xf1\x8a\x0f\x0f\xc7?\xe1\x17\x9a\x17\xc0~\x10'\x05mEA7\x8d\xd8"
        b'\xd9J7^:\xa4c\xd4\xf9 T \xaa@\xd7$J\x8e\x94\xedb\xb3M|\xf9\xafA\xf8\x19\xf0\xd9\x88>cT\xb2\xab\xb4\x8f^\xc4\xc5th\x17\x9b\xe3Wk\x9c\xd5E*\x81\xe4\xd8f\xd6G+q\xfdW\x86'
        b'G\xb6\x97\x90\x17\x11H~\x86\xcc\xdff\xfa\xd2\x07\x00\xb0\xe8\xc7\x98\xac`C\x16\x11\x8fJ\xba\xa7F\xe2\x7f(\xbf\x1f\xf4\xf4\xa4\xbb\xeb[5\x08T\x9f\xce\xef\xaf\xbe\xacD\xfbme\xba\xaf\xc2&?\xfc\xeaJ\x82\x9b'
        b'\x8b)\xfb\xa7\xb4\xa7,\xbc\xe3\xcd\x9b\x06)\\l\x1d\x9b\x12\xb4\xaa\x8f/\n\x00\xa07\xb2\x93\xc6\x89\xd3\xaf\x9b\x89\x93\xbf\x8e*29U6\x0f\xa8\x08\xd8\xdb3\x07_\x15p\xbfQ]\\\xd1\x12\xf9\t\xc7\xfe1\x16'
        b'u\xd1\x93x{\xc2\x8bt-W\xb8\x85\x13\xbd\x83\x06\xf5@\xae\x99\xa8=\x1e\xcf\xe2\x8a\x0eBm\xbf3[S\xf6\x9bT\xb2\xb0\xdbc\x0b\xd2X\xbe\xbc\xdf\x8f\xae~\x00\xe7\xd6\xf5(K\xeb0@\xaf\xada\x96.Y'
        b'[\xdb\x98\xab\xe30\xb8D\xb2)1A\xf5\xbe2\x0e\x0c\x91\x9f\x1a\n>\x90\x1b\xfc8\xa0\xfc"}\x1b\xeb\x96[\xde+g\xb9\xba\x87\xf4\xc7R\x06\x87[(\x8d\x11\xb5\x15~7\x1aTzv\xc3T&\xb2\x9e\xee\x9f'
        b'?\xa6\x86\xdd\xed#9*\x83J/\x94\xbfo+\xeb\xc4\x82\xd5b2\xc5(\xf9\x19\xe1*\xf9\x99\xe1PO\xadt\xb0\x18n \x97P\xa5\xb6Bq\xe3\xf7`\x15\xa4\xb2\x9eG7\xb7\x9b]\x06\x86&\xc3\x81\xdb\xf8\xfe'
        b'\xaa\x1b\xff\xf5\x8d\x94\xa7\x99&\xdf\xb5\x1b@\x02\xf5i\xe1U\xf6\xd8N6+\xdfYv\r\xc8\xa8O\xc8E\x85\xbfFE.+\x83\x8eE\x10\x15\xd1@A^\xc1\x84\x003ww\xd1I8\xbcjFJ\xd1gjZ'
        b"#\x1d\xf9\xd4\xc5o\xd1U\xe0]X|\x13\x86]8\x858f\xca\xd9N\xe4\xa0E\xaap\xcf\xeb\xcc\xbem\xa6^\xe4\xd0H(\xd4\x16}^\x81SIb\xde5\xfe\xb4\xe14\xc5D`\xd8(~D\xd1'\xbb\xd3\x8c"
        b'\xa1\xc4f\xc2\xf4A\xf6\x9e\xa2\t9\xe7\x0f\xc7\xabx\x04(\xddIu\x04E\xf3\xd5\x87.\xa8\xff\xb0+,\x0bn\x95z!\x05&<-\x0en\xbb\x04\xc9\xfb#\x8a\x80\x02\x1d`h\x97\x9f\x7fEi\x05\xe6\x03\xd2L'
        b'\'\xf2\x87;c\xf4P\x96\xf0;\xa0\xf5\x86;\x14\xfbe\x98\x9d\xd0l\x11\x97B\x9f\x05\xfelC\xbe\xc3\x94q\xdd/e\xad\xfb\xa8|(\xdf\xa4\xe4."Z\xfd\xf0\xcb\xca\x8f\xd4<\x1a\x02gG\xa0\xf3\xa8\x10\x9b\xbb'
        b'z\x0c\xab\xce\xe4\xe2\xab\xa0,\xf5\xc9\xf4\x16;Z\xce\xadS\xb9\xca\xb3\xce\xe0\xad\xf0\xcf\x8dw\xa3L\xd9\xb0\x81t.\xd2K\x1ai\x05\x8ci\x9e\x85\xb2>\xa4?\xedA\x04\xf6\xb5k\x00\x03gV\x05\xea|5\x92#'
        b'(\xa4\xc0i\xcfF\xae\x14m\xa9\x8f\x10w\xf9\x82 \xb3\t\xb1\x08\x0c\xc3\xbcx\xf4m9_\x07\xb4_\xed\x8d\xb3\xa4\xc5Q\t\xb6\xb2\x9e\xb3\x87\x10\xd8\xb60\x83\xb6B\x03\x11b\xdc\x9d\xf3\xc4\x0b)\xa7\x8b\x98~>'
        b'\x04\x8c\x02J\\\x85\x0e\xe2\xc7Y\xbd\xbb\x9a\x02\xaaz\xd5?\xed/u%\x8a\xde\x88\xe1|\x88E\xfe\x0fw\xe2"\x98R5<\xb2\xd9\t\x95\xa6,V\xb5?\x1c\r\xce\x8c\x1c"\x159A6\xa6\rl\xa5\x19\x95X'
        b'hR\x1dY#\x89\xdf/\xc0e\x05{qwa\x14\xee]\xebZn|\xff\x8a[=9\xc2\x81\xcf\x0c_\xf44X\xab/|Po/\xb7TT\x8bE|\xeb\xf4\xfe\xf9\xdc;\xf0$!\xc2\x86\xbe\x82*\xc5\x9c\xa8'
        b'\xe6\xca\xf0\xc7/\xdf\xb4V\x9d#R\x90\xbeV\x192\xed\x95\x1a\xdah\x9c\x0c\xab\x91\xf3\x07\x07\xcb2\x19\x81R\xdcD\x1f\x8f\xa1g\xb1\xcdk\x85h\x01O\xf6;.z\x86o\x07\xf8\x8c\xabj\x95}zw\x98l\x7f'
        b'\t\xe0\xb3s\xe0\x87\x107\xa4L\t\xa3\xdb\x83>\x1a6O*3v\x8a3\xcc\xe3\xaeg\x1a=<5\xbc\xc3\xfe}\xbd\xf2\x883\t\x9chP,\x041\x96\xf4\xc0\x02\xc3zex\x07F\x91,:\x1aw\x01\xe4\xdd'
        b'\x8b\xeb\x86\xf2\xba\xd6\t\xbag\xe0\xd2_8/\xd0F\x89\xc0\xc5I\xe7\xe3Nw~q\xb2M\xe9\x80,\xff\x8b\xe5\x91ik\xd3\x1a~\xc5\xcf\x85-,\x97\xe0k\xa5d\xd1\x11\xf9\xbex\x01\xa7\x8a\x87x\x98$y<'
        b'\xad\xef\xe3,5\xb8\xa3\x9a\xfc}PEd\x839\xf9\x1aF\xc7\xcd*~\xbd\xcciXcb\xcbw\xb3!HX\xe5 \x8bJP\x03\xc5o\x9aU\xca\x8dr\x0c\x07\x16\t\x8e\xbc)+\xa2\xf6Z\xe9zR\xee\xee\x06'
        b'`U\xde\xd4\xfe\x01\xc3\xa9\xca\x1dus^\x80\x95=\x12\x03\x8a?\x80L\xacw\xdc\xca\xf6\x874\xc1~vb\x84\xac\x18G\x11\xb0\xc2|\x11\x83\x9c\xb7\xff~>\xcf@\x8f\xa5^\x12wr\xce\x81\xed\xf5\xba\x8b1^'
        b'\xe4\xdb\x06\xa5\xd4=\xa9F&\xcd8\x9e\x84\xc5\x05J\xde]\xef\x82o?\x9e\x81G\x9b81`\x95\xc9\x8e\xe58c\xdf\x93\xc6l3o`\x15\xdf\xf8\x02;\xab\xd0p\xd6\xc9\xa5\x02\x98f7Z\xf8*V\xda\x7f\xf1'
        b'/\x8dmYBM|\x94(\xcc\x7f\xa2g\xe5\n\xfd\xc4DE\x9a8.`Ho.\x0f{\xc7\x1f\xab\xc3w\x9fj\xf0\xf3\xd4\x04\xcb\x89\x92\x01\x01w\xb2$\x19`\xd8y\xc0Eg\xb4\x8bOxEp\x87\xa0ME'
        b'\xb4\xe2\x1b\xfc\x0ex\xa14e`\xc1I\xa4\xad\x1a#\x0c\xd4\x87~\xa0\xb0\xb3\xcb\x82\xa1\x14F\x10Z\xae\xc3\rT5\x85z\xdf\xe8\xa4(\x96\x0fM\x915\xf2`\xe3\x94}wNCq\x85\xe3\r}\x1d\x1e\xcb~\xee'
        b'8\x9e\x0e\xada\xec\xfd\x89\xec \xa5\x92\x18P\xfe\x91\x19\x83\x07N\xd4`\xces\xdd\x17\r\xac\xf4\xc6s\xc7\xb8\xd3\x05\xda\xff\x95\xfb7\xe3%\x84\x8d\xbc\xd5k\xfe\x95Ie8\xef\xcb\xe4\x8f\xf3\x82\x1d\xbdOr\x1b\xcf'
        b"\x90wC\x0e\xce\x171'\x8b\xfb\x05\xbbh\x00v]<\xa5\xfc&h#\xa1\x8c\x022\xc6E^x\x82,\xa2\x91\xc5>[\xa4Y\x865\x05 &<,\xf3\xcf(-\x1bp~\x155\x19\x88K\xa0\xb8\t\xa7\x01\x9b"
        b'\x9aI]p\x9f\x94\t\xbc\x9bs\x82\xb8>u\xc4\x15\x8f\xbcph\xf1\xdbd\x15\xe5\x03\x87\x9f\x9b\x1a\x7f\xeb\xe9X;\xfcP6\tyQ%P\xc5\xf5\x1aE\x87\xf3e%\x82\r\x05\xbe\xd1\xd8%e\x1d\xa6\x8f=J'
        b"\x93\xc9\xc5\n\x98I\xcc\x85\xaa7\x1dT\x17\xa1\x1f\xc5>\xdb\x93'D\x98\x9b\xe0\x9e\x9a;\xf2\x91\xf2\t\x1a\xd1!t\xf8\x14\x07\xd9I<I\xa3@\xf9\xc4t\xe5oe\xe1'\x0c\xad8\xa7E\xf59\xe4\x0f[\xfdW"
        b'\x11$r\xdd\xcc\xb5Q\xa5\x1bm\xe6!\xc92\xbfj\xdc\x82/\x06\xddN1\xacz\xc4\xf0\xee\xac>\x17\xcc\\P_\x98\xc1\xcc\xb6~\x96-\x12#|Y\xa4w\xa9\xee\x07\xb4\xe7\xc2\t*U\xa2[\xec\xc8\xc1\x7f\xe4'
        b'N\xa8\xf5\xbaw\x0f\x8an\xeb+\xc6\xfa\x8d\x9b\x83\xea\xf5,R!\x93\xe1\xd8\x92\xe2\x8f\x91\xce5*St\x1d3\x92\xaa\x0f\xf5\xec3G\xf3\xf0\x8d\x8d\xf0\x9e\x85\xb1\x0f\xbai7\xcbi\x1e\xaeg1\x0cZ\xd9\xd7B'
        b'R\t\xbay\x99\x06\xf7\xe7\xac>\xae\x1eZ\xde\xf8\xd0\xad\x9bz\xb9\xcce\xc6\xebI4\x88$\x08\x9c\xcfGqg\xb4\xac\xa6\xd7\xbe\x964\x1f\xbf^&0\x9e?\xe4\xe7\xd8\xc6\xbc\xd2\xf2\xde/;b\xb7x\xd5IJ'
        b'\xd1,\xf6bX\x8f\x8e\x1f\x1ee\xcch\x7f\xa3\xd1\x90\x0b:\xaanZ\x94\xf6\\!%AB$\xe3\x92\xfd\xef\xbc\xaa\xebQ\xe0\xb9\x85\xfd\xff\x07\x94\xc4c\xe8\xbf\xb5\x92\x05D\x81|\x15\x9f\xba:w\xa6}Q\xf3\x9a'
        b'\xa8\xef\xb3\xc0\xa2*\xa1\x05q\xc3\x9a\xdeP\xbc\xcab(o|%\xbf\xb4\xe3;\xe3\xec\xa4\xd1C d\xa8\x10?"\xdc\xd2\x00\x058\x86^\x99N;>\xb0\rj\xc9C\xc6_\xbfp\xea\xa7\x9dK\xd1\xda4\xa2\xfc'
        b'\xb1\xb3~\xaa7\x16BP\x8a\xf8\xea\xf4\xc1\xc4,[\x88\xc4\xa1\xa1,,/\x9a\x9a\xef_\n\x10\xfb>RXw\xe6\xab\xf0\x80\xadWM\x94\xc9\x8b|\xfb\x91\x02\xa0\xecW\x8e\xd0j\xba\xf1L\xec\xa2}\xcbO\x1d\x07'
        b'L\xca\xf7\xa6K3M\x11`\xf2\xb1\xaa\x8eK\xbf\x17RB\x9e\xaf\x8c\xbe\x93eI\xdb\x98\xc1u\xb3P\x91\xac9=G\xf6\x08\x9c\x84\xad/t$\xa4:\x9a\x84{\xa3\x7f\xa6\xa9uS\xb7f`\x8b\x8a\xed\x11\xb1\x99'
        b'\xf5\xf3\xc4~\x1e\xdd\x9d\xddWuRb\xf4\x1a\xe1\x1cp\xa5PO\xac\x97\x04\xe2J\x8f\x1c/\x7f\xac\x1f\xba\x97B%\xca\x08\xe3\xaa\x1dRl\xc2\xd8/\xfd\x8c)\xe7\x0c-n/\xb6+\xf1.w[~\x10\xdf\xf5\x0b'
        b'\x1aD7!\xf7\xf4\xf8\xbb9(\xff\xf3\xd31E\xcd\xa9#\xca\xfa\x10\x93\xd3@\xf3\x14\x13\x99\x02A\xb8B\x0e\x10\\\xd0\x8f\xd3Q<)\x7f\x81\xe7S\x0f\x0c"\x82\x9b\x1a}\xad\xad\xb0\x80c\xdfU{\x0b\xd0(\xd5'
        b"'\x87C\x8a\xb6`(I\xd1(9\xa6]\xcb\xb6\na\xa8\xfe\x89\xa1r\x8b\xda;\x05a\xc1\x8e\x0b\xe2\xbf\xabs\xbbO5>\x08\xd0g\r\x81\xcbN{d8$\x0f=\xc5j\xc7\xbe\xc3\xb7O\xedT\x91\xf3\x1a\x1e"
        b'\xd9\xbb\xfbC\xec\x7f=[\xac\xb0\xd5#\x92\xa1\xfe\x0fs\xa8\xb5#\x85J3?q\x9f\x88\x0bf\xac\xc1\xd0N\x8d\x1dE\x17\xe8-\xb0\xcbuTC\xd8Hb\xc2y\xaeZ\xb5\xfcF\xe5+\x8d\xfe\x83\xc8\x87\xac\xa2\xe6'
        b'\xc8C\xee9N\xa3X5n\x16\xd4D\x8e\x85P\xe1\xa2\x16\xb7\x01t\xf5\xcb\x10n\xb9\\Nv\xba\x9a\x861\x9c\x83\x83\x9f\x00\xe0i\xf2\x9e\xad3\xe2\xd4.\xf8y\x80\xb6\x15\x05x\x05w=\x03\x1cT\x86\xc2v\xb6'
        b'\xcb\x84G\xeeWu\xf1\xd7X\xe1\x02\x00f\x11\xdbn~C-\xcc\xec\x0b\x8c8W\x07O\x15\x16z\xe1\xc7\x91\xa4\x05\x9b\x1c\x9d\xf9\xef\x15\xfa\x9a~~\xd0Y\t\x82\xcb\xe3.#\xc3\xfc\xaa\xf9\x173\x15\x8b\xee\xfa"'
        b'|{\xd8/\xac\x91\'\x9a=qV\xd6L\x8e\xa8\xd3#\x02=\xd3\xcc\x99\x0c\xd3\x88\xc5\xc8E\xdd+\xaf\xa8\x03"56\xf2\xfe\xf6\xf3\xc3\xb2\x98\xd3\x0c\x04v\xa2S\x02\xbc\xc1EL\x8aV\x16(/\x84\xe1\xfb\x05\x01'
        b'\x10\xb0~0\x1b\xd3*\xddd\xde\xd1T\xa1j\xb1VQ\xe0Ep\xe5"\x99\x98\xf7\x81\xed\xee/OxFg\xe3\xa1,\xb5\xef4:\n\xb6,:;\xe8\xe5\xa9\xd0\x16\xe9u\x12\xbae\x06\x03\xa9)E\xbbo\xd9\xef'
        b'E]C^D86]\x02\xf4\x06f\xff\x9c\xd5\x9a\xc1\x82\xf0\xcdF\xb6\xc2\x827\n\x15\x98a\xdd\xdeJ96\xa2\x8d\xcf\xa4\x8a\xbb9z\xac\xb0,\xa4\xffH\xa2tA\xf1\xcb\xfdU.\xe0M\x0bc\x8b\x80\r\x1f'
        b'\x92\xa1\xb7\xae\x15g\xa8Q\x96`\xde\xb510\xba8\xb0\x94p\xafK#\xbf\x07\xf2u\x01a\xc4\xd7\x92\xa7\xb6\xec\t\x1b]\xa4\nT\x18\xbf\x9a\xe7\xb1\xb4\xaa\x81\x95\x07V\x11"\xe5\xfeA\xf6O\xddN6\x18V\xe1'
        b'_bE\xb9\xb79\xa1\x9fh*\xb2\xa7\x9eWg\xc6\xc2\x06\xefYn\xbb\xc1j\xcd4S\xa4\x08\xfc\x08\xd7\x08i\xe8\xe7\xee\x9fm0\x16Bc\xb3\xc4`\xee\x05\xed\xdd\xf40nP\xd2C4\x13\x18\x9dA\xd0l\x96'
        b'\xca\xf8\xa6RS\x1ei\xe5{hU\x19\x1d\x121\xcc\x95:\xbb\x05\xad\x80\xd3\x15\xb6\xde\xbe\xf8^\xc3<\xb5nCi\xe8\xba\xad\xfbT\xb6\x9b\xd5i\xae\x16\xaa*de\x1d\x19\xb6\x9e\xf4c\xcee\x8f\x1a\xc0\xb6}\x7f'
        b'\r\xeb\xf5\x16t\xfb\xa1\x02\xd3j\x16\xd5i\x83\xe3\xf37k\x0fW\xdf/\xa6\xe5\x8f\xd2\x9e\xf2[\xe2tD\xb6\x894\x16\x90J}S9\x14\xae\xd3\xc8\xdd|;S\x9dV&\xf1\xaa\xe2\xd6r\x91LO\xd2/LJ'
        b'\xc9O\xb0\x80{;\x99\xbd\xa4\xa5,\x99\xac\xaba:7\x19<\xd1\x02\x80y\xa6\xd1\tkV\x11\x9f\x06\nw\xcb\xe3\x93C\xa6 \x14\xf4M\x0b\xdf\x02\x0e\xb4\x8c\xf7\x08J\x85\x9ba\x8b\xdeg\x03\r[\xc9\x06Z\xb3'
        b"\xda'\xd4q\x046\xb8G\xaeTI\x146\x16|A\xcc\xda\xf9Z\xb5\xc1\xa5\xd6_`\xc1\x94\xb0G\xa7\x88O\xe9\x96\xb4\xac\xbc\t?\xab\x8a\x96\xe9U\xcb\x0b\xeb\xe9;D\x9c9\xef\x93X\xe5\x0b!l\xb7\xd7X\xed"
        b'\x9eM\xec\x15Oz6aJo\x8e\xbf(\x1a6\x85`5\x9b\xfc\xd0\x1a"\x811\x12"\x1e\xf7\xdb\xf3\xc9\xaf\xc0\x902\x84h\x14\x85\x1d\x8d\xf6\xe5Ii\xc5\x1f\xb8\\:\xffs\xc8\xcb\xbe\xc0\t9\xf7\x12\xd4\n\xd0'
        b'm)$\xcc\\Nr\xb5PP\xccy\xae\xd3v\x04\xd7\xc9\xa5\x91\x01\xc3\xff\x06\xd5\xc8\xb07*\x9cZ?\xc8\xe5\xa66\xa7\xd39\x03\xa2\x93\xd8\x81\x9d7\xbaI\xd5m\xc3\xcdnD\xab\xf9thK\xc4u;\x85z'
        b'&`R\xdfSk/a(\x9aQ\x03\xcbD\\\x16\xf9\x82S\x0fG#\xbf\x8b\xe3\x1e\xba\xec~\xd36\xf8$k\xaf\x12\x82a\xb4\nS0\xee\xb0\xbeY\x86M\xc9KB\xbf\x9cs5f>\x0f\x92B\x8b\x81\x10\x92'
        b'\x14\x90]\x86\xe4N\xb0\x1fG\x161\x1e$\xb8P\xdeF\x1c\x8e\xa2.\xe0\xa2\xcc\x89\x8d\xa7\x98\xca\xa0\xea9>\x925(x\xb1\xcf5\x96\xcd\xe7\xbcF~\xf4D\xc0\xbd\xb0\x03\x8a\xea\xa9w\xcbQ\x06\\h\xce\xcb\xdc'
        b'\xe4x\xe5pD\xd3"\xe9\x85\x19X\xec\xb1\x19-\x15\xab\xba\x89\x1c\x1c\x1e\xabn\x90p\xf0\xe1G\x82\x99\x14\x0c\xe3\xb8\t\x11[\xadC\xdd6\x16\xc1\x02\x02\x0e*%l\xc1N\x90)\xd6\xa2\xd2\xdb\xc9\n\x08\xdb\xdcU'
        b'\r\xe8\xaf\x9c\x04@r\x0c\x17\x7f\x00\xd7\xc8\xe4/\x06\x8f\x9c\xf0\x85\x89a\xf7\xd6\xe9#\x9b\xd9\\\xd0\xf8\xd4y\xdf?\xee\xa0\xe1\xa7\xc6\x18\xc5H\xbe\x8d\x10\xcf\x03.X\xeb\xdb1\xa4\x8a\xa7>\x94\xee\x9fi\xef\xc4w'
        b'\xb1\x05 PAst\xd0\xad\xbc\x973\xed\x80\xf6\xe1\x01\x82\x8d\xd6\xa8\xee\x8e\xf6\xc1\x05V\xc7~\xf7\xaeA\x8b1\x9bq\x1d\xd0+\n/Q\x17\xd4\x04\xac\x85\x86\x94\xe1\xff\x99>"\xad\x9fc\xf3\xef\x13\x12\x1f~r'
        b"\x1a\x1d\xd4\xd2\xe5\xf2S\xdb\xd8GnK\x17\x86W\xc9\x81YG\x994v\xc4~r\x88L'\x08\xd4\x87&\\\x98+\xc2\xa3\xe2\xa0\xd3A\xe2\xaaG\x94\xe5w\xae<\xbaK \xf1#R\xed\xe0z\x84\x89\x8aKyw"
        b'c\xe7\xb5\xa3d\xca\xfc\xc3\xbf&;\xf27Qs\x81\xd7\xca\xf5\xb0\xb0\x083\x8a#\xdd\x81\xaf\xd4\xc4\x11\xf9<mR\xe0\x82 \x97a\xeef%\xeb\xbfN\xa9\x11zm\xf9`\xb6v\xbcMxHB\xca\x01n\xa0\xf3'
        b'\xc6\xfe>oEr\x98+\x08\x04!\xa9k\x93T\xcd\xf3#9\x9d\xaa\xb7<\x98\xf3t\x12\x88 K\xef\xc7\r\x00\x00%P\x95\x06\xc8*\\nz\xe0,\x1c\x07\t.\x06(h\xbd\xe5\x15\xa3\x99}mv\xcb\xf6\x95'
        b'\x88W \x18\x12_\xe3\xa1\x9a\xdd\x86\n-\xce<(\x99i+\x9b\xdd?\xd9\x8c\xb9\x91\x00\xcf\xc0qX\x9a\xa6y8\xe3+\xcb\x97\x9ca\xf9u\xfa\xcc.oZ\x8b\x1b/\xa2\x1d\t\xa6\x9d7\xd1\\\x9e~\xe3\x9f\xf2'
        b'@\xa2v#\xc3\x7f\x08w\xae\xac\x11$k\x18\xb9\xd7\xe1k\xd9\xc0\x8e\xa6M\x1e\x05\xaf\x1c\x08\xd8\xec,\\n\xc0me\x08\xaf\xd4\xdfB\x13\xf1OY\x9a\xe8\r1\xccR4&\x02\xd1Y\xc7{\x92\x17\xcb\\\x8d\x8b'
        b'-5K6<\xfb\xc8\xe7\xd5Qa]\xf5\xe8r\xa6\xac\xa1\x08uBx\xc18\xbe\xb0\xc2MtUT\xd6\xc7\xd7\xc1}\x99\x9d\x10L?A\x1e\xd2\x1d\x95\x13\x9eB\xf7\x16\x0e&l\xb3\x18\x0f!\x87\xdc\x83z&\x10'
        b'e\x97ic r\x8e*\xae\xab)\xb11It\xb8\x07\x9a\xff\xabAT3\xfa\xd8o`\x97AD\x8b\x8e\xeb\x93\xcf\xb6\xd4\x85R\x93\xf7l\xd92\x07\xd5n\xcbB\xe3\xb9\xd3TB\x9f,;,\x19\xf7\xb5\n\xa2\xde'
        b'\xeb\xb6\x9d\x07K\xc2\xd2f\xafA\xc2\xf1\x0f\x04q\x14j\xa3k\x05\x08\x14\xefG\xa8b\xfb5\x10y\xc8(K`\xe8|I\x7f!\x0c\x9dnEnu\x84\xd1\x86\x05z\x89&>9\xca\xc5\xab,4\x89W\x12\xff\xf6'
        b"\xd6,\x0bd<\x805\xe1Uu\x1b'@R\xf5\xb6v\xc5jv\x8d\xec&\xe54g\x87\xe7\xf9\xfa\rt\xe9 \xe3D!7\xf7+\xa2\x19\xf4\xcc\xd8H\xb0\xe0\x14\xb7\xc27\xe6\xc3\x1fB6[\xe8\\>\xb3\xf5\x82"
        b'ju\xe9-d\xc3\x1fO\x85cN\xef\xf5Loxv\xa1\xef\xabk{\xdb\xbbI$\xfc\x99@\x91\xc6\xed\x9d\x02\xf3(\xfa\xee\x98&\xd9\xaa\x91Q\xda\xedS\x83+/sF\x0c"A/\xc9\x1df#&\x91\xe0\xc2'
        b"\xfdS\xa6G\xb5\xa2/d$\xae\xeb\xbc\xf2`K\x0c\x95Xb\xbbA\xde\xcc\xc6\xd5\x888cwL[L'\x85\xfc+\x88\xd0\xcf\x1c\x13\xbeq\x9eQ9x\x16\xc6\xf2\xc2\xbc\xdc D\xae\xae|\xb7\xbcG?g\xfb"
        b'\xfd\x95\xde\x12\xec\x94\x7f}\x11\xe9d\xd7$\x84;.\x11\xc7"\xccj\xf8kD\x17\xc1\x0b^\xad\xd2\x1d\x9c\xabw\x95(\xfe\xb3\xb1l\xeaj\xab;H+\x84e\xd2\x06\xb7\xcao\xce+\xd5\xa9\xd7\xe7\xa3e\xc1A\x9c'
        b'I"$\xa1\xc6\x0f0\xc39\xfc_\xfe\xf6\x8f\x9byGTUq~\xf1Pah>@\x1a\xf3\x88\xbd\xa0\x89\xd4\x1f \x9a)+$\xc5\x07\xe3\x03\x85\xcdl\x15\xf4F\xb0>[\xb4\xb4\x11MP\xb4\x1bT\xafr\x13'
        b"\xe4\xe6\xd1S\xfe\xe2\xab\x08'\x00\x02\r\xdb\x9aK\x12\x83\xfaL\x1b:\x19\xeb\xcb|\x85k\x861\r\xf4\\\x94B\xa4\xa5\xd4/\x8am\xaf\x06\xa6+\xd5\x0b\xe2\x0c\xb9\x7f\x84*G\xe1\xe4\xac\x11\x04\xbe\xdb\x15\t\xaf*"
        b'\xb4q\xd9\xc7\x9dG\xc9\xf4=\x7fZ?1//\x08\xef\x84*\xf1 \xa8x\xf3+`\x8d\\X\x94T\x8a\x07\xd4\x87\xa7^a\xdf\xb8i\x81\xb0E\xff\xbf\x8ao0x9 \x8f8X\xf3\x96\xc8H;y\xf4\x85\xcb'
        b"EE*o\xb7\x7f\xad\xd7\x90G`Y.4\xfe\xdaJ\xa1\xed5\xd3\xdd\x15RuN__)\xfb\xf5y\xe9N\xd7B\x88\xbdtkn\x0c\xee\xfcw\x01*\xd8\xc0xf\x8a(?\x1d\xe0\xe5\xd9\xd5\x86\xca\xea'\xb4"
        b'~\xe4u\xe1\xee\x8c\xc7`\xec\r\x95D\x86\xa9\xe5\xedDg\x96E\x0f\xbd\t\xb5Z\x9dB\x9a\x1e\x1a\xf1^\xd5\x03\xddW\x1cJ\xfbV\xc6\xed\x95Oj\x08\x1a\xd3(\xc0\xe5\xb6\xc9\x80\xfa\xfa\x17\xb1\x16m\xf3{\x08\xf3'
        b'\x87\xcd|\tz\xe97\xaa\x9a\xad}4\xfe_\x16W\x87W\xd0\x85\xbaB\x82Y\xb9p\xdc\xbf\x8d\xb5\x85\xf5\xda\xbd\xb7R\x1f\x89\xb0\xef\x9e\xac\x12\x9ff=\x8d\x99\x8f\xb7L\x1f\x85\xf0\x96\x82\xa4\xdf%\xf7\x8b9\xc2`'
        b"\xd1\xfc3O\x81\x07\xd5\x84&a\xfc\xa5}s\xcc\x86\xf6\tr*\x1cT\xefW\xe8\x1e\xa3\xa8EU\xb7\xa2@\x8b\x8b\x89\x84\xfd1\xee<X\xbeB\xcf\xd8\x84\x16\xfcQ\xa3\xedJD'O?\xda\x9d\xbc\xe2|\xb16"
        b'#\xfe\xa6\xe2\x19\xc8P\xfe\tB\x12\xb8y\x0bI,0(\xd7\xe9]\xe1\x9aBPO4\xf8\xca?\x99\xbf\xb4\x88\x96\x89|\xe1\x8aZa\x0fnms\xc1\xa1\x19\x98JW\xe4P_\xd5V\xd72\xcfv^W^5'
        b'T\x0c\x94\x8e,\xb2\x91+\xfb\xddf\xf5i+\xfa\xbe\xd3C\r\x82\x1d\xf9\xb8Y\x04D\x91\xd0\x9c\xf7\xf4\xce\x93(\xcd\x8b>\xfbv\xf2\x00]\x05\x027\xca\x89\x1c\xca\xde\xef\xc2D\xb0\xdf\xbe\r\x8e\xdd\xfeQ\xd7JS'
        b'zx\x08\x10)\xaeD7\xb0\x80q\xd2\x96\xbc\x97p\xe88/\x1e<\xff\xeds\xbfG\x14\x16\xa9"F"]&\x9c\xea\xf3\xb4\xd4M\x14\xbf/I\xbe\x91\xb1\xe7\x1b=\xa5\xc0\x07\x0c\x8e\xca\xb6\xda\x16\xb3=-Ky'
        b"N;\xcf1\xc7:\x1c3\xb5'\xdf\xee\x03x\xbb\x874a\xc0]\xbeM\x01\xcf\x98K\x9b\xf0\xd4\x89\x9a\xf2\xf5(\x04\x04]{\xc1*D\xe9\xd6\xb2P\x0eK\xd7\xf6/\x973s\x8b%\xf90\xdd\x15\xbd<V\x8c\x1a"
        b'\xcb\x80\x84\xfe\x10\xbdJ8\xe5\xb3\xb9\xf4\x15\xaa\xe1\xe3\xc54\xe9\x9ce[\\\xc7\xab\xd0\x7f$;-\xa2jE\xb8v\xb8T\xfa\xae\xcfV\xb5\x99`\xd9"\x9e\x896Z\x06}{V\x01#\x105\xce~7\xa0\xadB'
        b'\xb2D\xad\xec4%\n8;F4\xae\xd4@\xb7\\$\xae-\x04\xd4\x9b\xc5\x16\x8c\xb5\xbe#\xd95\xf9Lt\x16\xd88\xca\x9e\xa5\x15hq,\xe9~\x97\xe6W:\xe2\x01\xef\x88\x9d\xadLh\xfe\xd0\xed\xb2:\x92\xd5'
        b'\xa2T\x19\xce\x05x\xdc\x0f\xdd\xccK\xb3z+x\xdf\x86\xf7\xe3\xa5V{%\xdb\xb8\xf4\n\x80\x17\x81\xcd\x91\xd9\xeb\x93-\x0e`\xb3+M\xdbKXBY\xf6\xb0e\xc0\xe9\xc6(5O\xd8\xa2T\xe3\xe33\x99\xb7\x02'
        b'\xf6\xe2\xebZv1\x94\xc6*&\x94\x96\x1bs\xb7\x12|\xbe\x9e\x1eBv*P]z>\xc9\xd7\xc9\xeb\x18i\x85\xb1a\xb4\x19\x91\x0cBy\x02\xa7\x10\xf5\xbe\xac\xdd8\x9e\xc6\xce\xc1a\xc2\xe7\x81\xc6\xbdg\x8a\n8'
        b"\xdf\xac\xaa\x8et\x18>\x00'\xd7\x9d\xc1m\xa2\x05L9\xe2+\xfa\x98z\xc8X\x8f\x1a\xee\xb7\xcf]\x99\xd6\x04\xba^\n\x17\xa5w\x1c\xeb;\xe8\xd3\x92[Z\x168]\xf6\x89\xdd\xc4\xb4j\xf3\xb6\xedJ*\xdd\x1e\x9a"
        b'\x81\xc1g\x81:\xc0XR\xfa\x075\xf0\xe8\xe86\x98"\x90\x8e\xfb{j\xd6;1\xa1\x035\xba\x9c\x1f\x1f?\x1e\x8c[\t\x9a\xfd\x9c\x93\x80O(\xc2\x9dB-p\xe4\xec\x9c\xa1E\xf7\x05\xb2\xfa\xbdO\xef\xa8WP'
        b'c\x87\xec@\xe2\xf8\xf6\x0e;\xcdP\xec\xbdy\x15\xbe\x95\x83,\x87MP\xc7\x87\xdbH@\xc5\xad\x8fA\xcb^\x86\x17\x9a`\x15P\x10@\xb0`=\xa4\xe0I\x9fE\xfdz\x99n;\x13b\xc4D\x98\x81\xfdp\x8eD'
        b'RE\x94D\xa5\xef\xe0\xef\xafY\xff\x05\xee!\xa8\x00\xae8\xb5\xe4J\xf2x\xce\xee\x82\xd8E&\xdftt\xc5\xd2\xe8\xb9\xe0\x04\xbb\xd7Q$K\xcbV\xd07\xd2\x8f\xbf\xca+\x0f\x1aS\xbfAY\xaa\xbfw\x8f\x9c1'
        b'\xc9o\x14\xef\x01I8\xeeV\xbd\x04i\xb5(\x8e8p/\xe1~\x8d\x8f\xa3A\xfc@t\xe7*\xc1B\xc0\xf5(\x97\xa6\xbf\xc5\x0c\x91\t\x8d\xd6\xcf\x18SOn\x05^\xf1$\x0ew>\x18cr:\x85;\xce\xd2h'
        b'C\xd2\xc4\x11\x16mE1\xd82\xfb\r\xec\xf1s\xbd\xe5\x85\x0cM\xa2\xf6\xa0\xaa\'\x15v"\xddP\xeer\xf0\x04\x18\xe3i1)\xc6X\x15U\x11Bs2\xc9:Ir\xa4\x84"\x0f\x88\xc9\x0c\xdf\xb5Ys\xfek'
        b'\xa8_\x0e\x97\xfc.\x1f\xa0\xc8I\xd2e:\xe7 [ *\xef\x86#\xc4\x1f\xa2\xe3l\xa6\x87Fn\xe1\xd7\x0e\xb4\xce\x8fg\x83\xc0\xb9\x90\n%\x9c\xb7\xe3\x8d\x1f?,\xfc\x1c}\xd8s!)\x96\xfaz\xf7\x18-\x7f'
        b"\x05#?\x8b\xe9\xa4\xb9GT\x9c\x15\xd8\x80m\xf69\x82m(\x1c\x9b\x1ee\xf1\xe7\xc2\xcf>P\xfdE\x9dZ\x1aW\xa4\x1d\xfd(\x9a\x9f@\x8dO\n'\xd77\xd3\xd0\xe8(0ML\x89\xaa\xfdj,\xd4H\x93\x07"
        b'/\xc1\xb18\xd1\x15\\\x8cv\xb1\x02q\x94e?\xea\xba\xd9V|2\x00\x8a\x85h\x84\x9a\xb0\xc5\xf5L\xf5|\x85\x16\x98\xf6\xdeO\x94\x89\xa7\xf0dz\xf5QM\xd4\x80c\x13v!\xfb\x01\xaf7t\xa3\xb5\x8a\xe3e'
        b"\x90i\rl\x98\xbfh\x85j\x17\x1c\x95@\x8df?Z\xea\xdb~\x12C\x8cX\x8c\xd3\x16\xba\xf8`|\xc9\xfb\x86\xec\xef!\xb8\xa8n4K\x94_\xab\x01\x87\x0b\x8a\x06.'~\r\xb7\xee\xf5\x9a\xc3O\x9caG\x9f"
        b'\xb2f$\xa9\t\x1c\xfe\xe1\xeb\x98\x03\xdf\x073\xd2\xb4\x17\xbf\xe8\xce\xafL<M\xf0\xc4\xa9\x1a\xc7\xb7\xa5L\xf74\xae}R\x0fgIl4\xa6\xb8b\x9d-\xcd\xa3"\xa6\xe2\x9dcL\x82\xbe\tHH5;!\x8a'
        b'\x0crEP\xe9\x96\xfcX\xf4\x02\xa3JB\x1f\xba\xca i\xd8\xa4\xa25\xe3!\x1c]J"y \x8f5\\\\ry\x827?(*&\xf9\x93\x1b@\xb9T\x1b\xa0C\x16\xab\x07,\xdegK,,\x14\xbd\x15\xb3'
        b'\xb9\xa3t\x04\xf5S\x06\xcf\xfd]\xd8\xbd\x17\xd6(st\x8e#G\xc8\x00\x87\x88\xed\x16\xc9\x03L\xdf\xfc\xce\xf2\x0c\x94\xe3\x97<\x91\xd0hCvk\x08\x966I\xef\x9a\xd9\xc3e\xfa\x07!\xd4*\x13Nl\x99\xac\xa8'
        b'4\xf2\x1c\xc2W\x84\x9e\xf1D\xb766X^\x03\xcb\xa5\n\xf0\x13\x04\rW\x7f\xca{\xf0\x9e\x85\x0b\xa8\xe9\xbd\xfd\xf8\xc2\x007\xf6\xee\x06\xb53\xb5\xc0\xd3\x0e#\x9eA\x82\x82\xa4F[\x12\xba\xbf\xdc\xbc\x03\x9dX\x8c'
        b'\xe1q\xe1\xea\xc7\x17\x13\xb8\t\xcbi\x14\x06\xbd\x8e\x85\xf01=\xce\x16\x17\x93i>\rt\xfe\xac\x96\x8b\xc7\xd0\x9fB\xed\xaf87\x1d\x1fi\xdc\xf4\x83\xb4\xbdi(\xb7\n\xea\x98$>W\xd9k\xbc0\x94\xd3mW'
        b'\r>\xfe\xed\x05\x13/\xca\x16\x0e\x8c\xff\x92\x054\xa09$\xf6Y\xc2u\xe7\x8b\xf4\xb9\x82X\x1a.\x1e\x9e\x06\xe0k\x1b\xaf\xf4\xc1\xb8\x80\x9b\xfeC4\xe5\x9el\xbd\xe2\xe4\xaa\xf1G\xa9\x9c\xc2H\x8c{c\xe49L'
        b'\x06\xa2u[\xa5\xb4\xe5R \x08\xd5\xf6\xca<\xbbV\xbb\x1e\x94\x18\x1b\x05\xb7h\x9d\xd7\xe9\x85\xe7\xe0\xc0y\x17\xcd\x11d\xcc\x8fR\x10\xc0H\x87\x94\x833\xc4\xa6\x06Ee,x\x00\xf0\xb4\x13\xef\xf6$\xfbc\x16E'
        b'\xd3\n\xb89\x0c?\x98\xbc\x92\xcd\xff\xc8j\x9e\xfd\x11\xd4\xec&\xfefg\x88\xc5E\x07\\\xbe\xcb\xd4\xc0\xb7PB\xe1\xa2\xf1oSNQ|\xa7\x08\xabm\x03*00\xc1O\xde\x8b\x14a\x08&\xc02b\x0c\x8c!'
        b'o\xae\xc2V\xb8t\xf2\xed\x1cW\xb6^YF\x0f\x7fS\x99vA\xe3Tx\xf6\r\xaf\xad\x92\xb4\xac\x11\xd8\xd6\x86\xc5\xbb\x89 b\x94\xcf\xf53\xc8\xe1:\x83\xbb\x86\x8e.5\x08\xd0\x83\x8f\xc0\xd24\xa7\x1e\x12\x8d\xd6'
        b"\xe7\xae\xa4\xf8\xf0l\x8c\xf0\tQ\xb3\x83\xafU\xdb\x90\xedy(@\xa8\x83\xe3\x04\xab\x11\xfa\xf8'\xa9\xe0\xa1\x0bb\x86\x08\xd6z.\xd6D\xa8\xb7\xf4\xd3\xcb\xb2\xc9)\x98\x0eZ\xebi\xc8x\x817L+\x0b\xb6\xd8a"
        b'U3\xec\x8b{\x86\x94\x1cA\xc7]\xd5\xf6\x02\xe5\xd0u\xa7[6<\xd1:\xfd\xbb\xf2\xf5\x0c\xc3\xadkbP\x08\xcf\xb0Z\x1b\xdfCZ8\xcd8V\x07\x00u:\x02|\xb4\x1e\x7f\x9bb.,\x95\x15\x90\xae<\x01'
        b'K.(\x038\x0b\xfa\xcc\x8c\xac\xfa\xbf\x87\x15\xcb\x126\x11\x08w\xa3\x8d7\xee\xd7p\xfbe&\xca7=\xce\xb2\x96\x9d\xcdh\xd4\x80\xb0\x91\xff\xcd\xd7\xcb\x1dI\xce^\xad\xd9\xb8\x97\xf5\xdd\xecO#\x99}\xe3\xb4\x1d'
        b"+\xa6\x97\xb3\x89w\xca\x1b\xba\x85\x0e'(t\x85l\xd4\n\x1fh5o\xf7.\xefn~(w\x82\xf4f\xddv\xc6\x89\xb5$k\x81\x04\xd0\xd9\x97\xd0\xcd\xd6U\xa6\xc0\xdd\x8cg\x84\xf9r\x93$:\x87\xe4\xb6\x80\xf6"
        b'\xd9\x0b\xa4\x1d\x0c\xc2\xc1p=\xe3\x94\x17W\xa8\xaf\x80D\xcd\x92\xfc\xed\xed\xa1\xd7M\xc0\xe3\x02\x9d\xbe\x89+W\x87\xaa\x02\x9c\xce\x1bs\xa6\x1c-<\x96\xfa\xf2\xd5p\x13#\xc9a\x8aB5\xf9T\\J8\\\x8c@'
        b'?5]\xfd\xbd\x00\x85\xa8<\xc8\xb1\x95\xcb\xa8CF\xc5_$\xb7Yc){\xa3\xa7\xb9\x19P\xab\x0b-\xac\x05\xb2\x8a.\x99\xf8m\x1e\x1d\xcd\xd4o\x0cJ\x12\xackv\xb0\xa6\x8cb\xab\x16C\xdfD+\xa7\x0b\x1d'
        b'\xe0>\xad\x10\x9bP.>\x03\xedb\xe8\xe1\xb7\x96\x80f\xa1\xd4\x9e\xc0($\xee\xa7\xccv\x85\xecC\xb1\x18,\xa9\xc0\xbc\xc3\xd8\x11o\x0c\x90_7~\xb2C\xac\xed\xf8\x92\xfe\xfb"\x84\x01}|e5y\x0c\x8f\x08'
        b'_\xf5\x10\x9c\xf0p\xe6\xd6\x81\x1c\xce\xa5\xf4\xb7\xa4\xf5\x89\x07\xd0\xfe\xed\xfd\x15k<\x1b\xc8\x80HD\xb8\x0e\x91,\xcd\xeb\xdf\xb5`\x86\xacn\r\xeb\xe8`U\xce\xd6\x89\xebL\x94E`\xaf\x9b\xaf\xbb\x81\x10\xaa\xd7\x9f'
        b'jTN]\x9c\xdc\x88\xa6\x00\x8bD\x12I\x90\x14\xcd\x9c\xa1\xca\xf7@h+\xae\x86b\xf9L\xf7\xca"\xc6\xcc\xf1\xa4]\xaesn\xb8<&\xba\x08\x9f\x95O\xe8\xfb:\x1f\xe5\x89\xbd\xa7\xfd\xbd\x910\xd3\xf8s\x1c\x03'
        b'\x85\xce\x98\x12)\x1b\xdcovM\x89t\x83\xf2\x9dt\x08*\xc4\xbc\x8d\x06\xcfp\xfd\xcdvi\x1f\xcf\xec0T\x02\xe4\x15\xfa\x9b\xe5\xaarB\x8f\x91lV\xd7\xcd\x01\xaeG\x1e%\x8a\x13\xb7\x04\xbav\xe4\x16\xcc\xaca'
        b'\xa2\x14\xb2\xc2Cr,\xf1\xcc@\xcbG\xef\x87\\k\xef\x8b\x02\x9f\xc5\xdfK\x02\xb1\x95\x80\x86K\xd9P}\xa7-\x13P%OjIC\xde\xf3\xe3\x0e\xe5\x8c\xa9\xaa\xfcE\xcf*+\xa1%\x9d\xdd\xe5\xcd\x84\xa4\xe5\xd9'
        b'g\x98\xbb7\xa6s\xebI\x0cJ\x90\x8b:\xbc\x98\xffs\xe8\x1f\xf0rS\t\xc3\x1av\xb4\xe9\x08\x9fgX?n\xbfv\xa3\xf1}\xa2\xe2-\xee\xbb\x9c\xbf\xe8\xff\xea\x8d\x82\xd0\x83\xd9\x0e#b95\xb8$J0\xe2'
        b'\xd9k\xf5u,!\xf4WXq\x0fD\xb8\xae\xbbs\xa5\x91\xb0~\xb3.\xf5\x94_\x92\xdc\xb0\x15\x89\xe8\xdc\xf1s\xc8?\xb9\xaa\x88K\xa7\xbfB\xdd\xfdqT%\xceK\xbcO\xe2\x96\xd2\xc6\xc6 #\xaf\x12T,\x8d'
        b'\x00-p\x90\xb6\xf6\xac\xd4<3\xb3\xaf\n\\;\xb2\xab,"\xc4s\xf4\x19\x13\x94\x0eM?\x9eaw\xe7\x1a+>\xb6\xb0Y\xda\xbc0\x8b\xa2{\xc7\x93!\xec\xeb0\x87(<\xe8\x0cvP"t\x1c\xdaBj`'
        b'\xc6\x98\xb4\x81\x9e\xf7\xad\xb8,O\xcd"\xd4n\xf0\xd6Px\x93\x90F\x9c\xc7\x0b+\x9f\x94\x9d\xf6\xa2\x8d\xf8PP\xb3\xcf\xf49\x12\xc0\xb2\x88~\xa9y\xabX\x1fM\xfc\x04\xfc\x80z\xe6\xbe\xf5\xae\xbf$*mVp'
        b'\x11\xe2V\xbc\xdc\x08a\x7f\xdb\xf1p\xe0\x19\xd37E\xb4/(H\x91\xf6we\x87R\xff \xce\xab~S\x05T\x8b!QO\x96\xba\xe3\x08\x01\xca\x95\x93}-\xa7@/x\xcc-\xb2\xf6\x92i)1\xbam\xe5\xd2'
        b'\xbbN\x1a\x14\xe7M\x81\xe9^\x0c%\xb8\xa0\xdd@\xda_\xdb4/\xe5\xe5S\xee~\x11\xd2^u\xe00\xdc\xbe\xef\x11\xb1\x12\x1b_\x88\x85z-+\xf6[#\x96yW(C+$\xb2\xb0W\x84\xf5\xf5\xa0.\xd2O'
        b'\x17\x81)\x08\x9d7?\xa8j\xba0\xdc\x1b\x1au\x18\xf9\xb2o}\x8e\xed\xb9\x1b\x9e\xc1\xb8\xb4\x9e\\\xf8\xd73\xc5\xaan(\xe0Zi\xe9V\x0c^\xed\x9eFG\xb6:\xbf\t\xc2N\x97\xc1\x87\x1dw\xeb\xa0\xab\xfca'
        b'\x8bx\xda8\x8a\xe9\x93\xa8\xffi\xe3\x7f\x1b\xd8\x1dL\x8e\xf3\x11\xbf\xf1I2\x9c2TA\xcctG\xb7)S\xb3\xe4`\x8e\x00\x9c\x14\x9e\xda\x93\xded\xf2b\xff\x90\xcb4\x7f\x1b\x8d\x05f\x1f\xc2"-%_J5'
        b"f\x87\x92\x1fnR\xc2<\x98\xdb+\xdc|\r\\\xf6a\x82`\xb8\xc6\xb1\xb4\x0e\x04\xabX\x88\x81s8\xb4\xd3\x93\x8f \x9c\xf5\xdf\xce\xcbu\xf7iT\xbd\xceW\x82I\xc0='R4\x83\x7fT~Z4\xa4\x9d-"
        b'\xd7\xd0\xaerY{\x13-4\xb4\xcfW\x10\xc4\x97\xb4\x8e[\xee\xca\xe1\xa9\xd59\xa0\xc7W\x04\xf5!\xf3M\xea\xb9e\xe7\xf1MEMX\x12\xfa\xb0\x01jZ\x7f\xdbsk#G=<\x0f\x04O\xa3!\x18w$\x98'
        b'\xce1Yh\xf6LD4=W\xa0z\xfd[j\xc4g\xb1\xe9\x9a\xd1\x85-\x0c\xdb\xf6x\xe7l\xa0\xea]\x824l\xf7\x1e\xf3\xc0\x85\xb8\x15\xa8u\x98\x1a\xc8:\xf1paG\x0f\xe8\xa7\xefY4\xc7()\x90\x00\x96'
        b"\xcf\xca\xe8\xf3'\xcd\x14hyk\xdd\xa2>\x9ax\x88\x98\xc0P\xc6M\xb1\xdeLo\xc5\x93g-\x0f\x89\x04\x98\xb4\xdb\x97\xca8\x87\x9c\x12\xeez\xe6\x1c\x80\t\t\x06\x14\x06\xe8uE\x18\x90\x13\xd4\x18\xa9\x92&\xdeK"
        b'\xc5\xef\xe0\xa3\x97;^8\xec0Q\xb7\xeb\xf0\x8b\xa9h\x94\xa8a\xb5\xe7)\xedM\x84qc\x93\x96\x0c\xfd\xe6{\xe2\x80\xd9UF\xa2\xfeh\x07\x92\xe2C\xf4\xf1#m V.\x83\x9a\xb8\xeb\x83x\x8d!\xb4\xcd\xf9'
        b'l0\x8eO+-\xafs\xa0\xb2\xe3\rh\xf4\xaa\x17\x1d@P\xd4\x8b\xd4q7Hw\x86\x8a@\x106!1H\xd5I\xeelz\xadpck\x1f\xce\xafo\xd3+\xf6r\xd5\xb5\xaf\x80,:\xa56S\xbf\xf9%\xf9'
        b'\xc8\x1f\xee\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00'
        b'\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x04\x00\x00\x00\n\x01\x14\x01'
    ))
