
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x020\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds2.\x00\x00PYARMOR\x00\x00\x03\t\x00a\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\xf2-\x00\x00\x00\x00\x00\x00\x9a\xd9-\xaf y#\x9dQ\x7f\xbfw\x9b\xb1S<\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2a0\x8e\xc4\xaa?\xdfr\xa8y9\xaew01{W\x1fv\x9cH\x93\xd967\xb1\xaf\x98!&*\xa6d>\x13\xf4y\xd6\xb5&y8\x05Kf\xcf8"\x0e\x92\xc9\t\xe5'
        b'\xac\xa7\xe0\x8a\xd0\x07\x06L"\xae\x1d4\x8b"r\xf5\x13\xc8\xc2\xbc\x1e\xb2\x99\x1a\xb6\x15J\x03lA7x%\xdd+\x16vjdWM\xc0\xf0v\xa2\xd7_E\xbcdR\xe7\xf2\xed+\xd4Zn\x90\x12I@\x15\xbc'
        b"_/Vz\xf2\xbf\xed\x13#\x8arJ\xab\x03\xa0\xf7\xaf\xbe\x95\x9c\xd1\xc8\xc5\xa5n\x8d\xac\x07\xb0\xe0m+x}\xf7\x07\r\x10\xe2!#{\xd9\x17\xafuw\xec%>3\xe8u\x88'[\xc9\xac5\xf7YH#."
        b'\x1e\x80\x02Q\xc4f\xb3\x86\x8c\xb7\xb9\xd4n\xf5\xd3W\x8f&j\xed\xbd\xb8;\x03\xb7\xc1K~Y\xef\r\xbf\xd2\xb4)\xb61\x8eGl7\xe1\x99#R\xeb\x8f\xefO\xa5\xd1\xb5\xdc\x90\x13\xf1;\xab\xc7\xe5\x8e\x1c\xb4\xbe'
        b'\xd4\xb6G\x9b\xe5e\xdfn\x17\xf9\xd4"iG6\x1dU\xa2\x16\xf8\xce~P\xe4@"\xde\xa1\x07A\x96\xc1|A\xc8+1\xd29\xe4\xe7+~\x1b\x168|L\x96\'e\xfcdr6^\xdd\xc9\x86WD\x96Z\x89'
        b'\xbc\xca\x0c\xd0\xfc\x16\x04\x19"B\xf1\xa4\x9c\xb9\xbf\xf9Q}0L\x00\x93\xed\x1b\xbfw\xbaJSt\xd4_\x14\x97\x15\x0c\x0b\x14\xf0\xee\xeca&\x17\xef\xc8\xb9G\x93Q\x96W\xbe]\xf0\x9f\xcf\xdb\r5\x93\x1c\x8f7'
        b'\x9e!\xc2j\x14\x87i?\x07.\xf0\xecF\x1c\xc9\xbf\xd8\x11\xd7\xc42\x05i^ S<y\x0b\x91\x91%\x18\x15d\x82\x08\x00k/ \x17"\x85\x1e\xc3\x90&u\xf2\r\xa8\xe4\xa9\x12_\xed\x9bv}\x8daq|'
        b'\xec\xd7\xbcG~\x93\xbc0\x1cWP$\xefn\x99p)\xe5\xdczX\xc0\xd4g\xb5\xae\x11\x1e\xe8\xacO\xb4\x03\xc8\xfeI\x97+\xf9\xea\x83^g\xba\xa3\x84\n!\xca\xb4\x04\xab\xed\x9a\x8c\x12\x16z!\x13\x06\xd7\x9av'
        b'Z\x9f\x9c\x98M\xbe\xb7p\x0cX\xa5\x05Oh\xac\xb2\xc1%;\xd0\xf5L\xb9\xa4\xaf\t8\x94g\x9e\x93\xa4^\xae\rj\xa4dU\x94\xcbN\xf2[\xef\xe6,\x18\xdd\x1bb:\xb5\x1bt\xfeB\xcfZ\xfb\xd7\xe3#\xdb'
        b"l\x88I\xee9A{GL\xb6h\xb1\x1f2\xdd+\xc4U'\xe2\x81Q\xb1|\xbb\x04\xa1\x89\x1dk\xe07\xd6\x8a\x10\x9b\x92\xca\x0e\x9c\x99\xf2\xc3\x89\xdc;\x05\x8c\x96\x81A\x11|\x11qrr\xcfD\x06\xc4\xee_\x00"
        b"\xfe~8F\x92D\x1a\xfa\x80\x00\x88\x8ape\x84m\xcc,>\r\xe4\xf8Lb\xfdI\x0fGS\xabgrc\xe8\x98\x88C\xbb\x1fd\xddu*\xff\xc0\xef\xbf8\x8f'\x11\xb6\x18N\x118\x17+\x95\x8a\xa8\x84e\xe4"
        b'\x15\xa4\xe9\x06\x01.\x9f\xc02\x07M\xfb\xa9$D{x5\xa5=\x92\xcf[\xfe\xdd!>\x84\xf4t\xc4\x07\x17\x01\x11\xc4\xf9\x10\xd9\xe3\n@n\xcdQN\x13x\x00+\xbf]\x8b\xf4/\xd2n\x927\x96\xd2>\xee!'
        b'\xd6\x8eM\xeb?y\xa50NS\x1b\xcc\xb3\x00j\x92\xb0\x98\xb7\x119\xb8\xb1R\x10\x0b\xd6\xa7j\xefU\xf8\xa5xk\xdd\n\xe7\xa4\xf6\xa4`\x10\xff\x87\x14#\x02\x8c\x9a8l\xb8\xf3E\xecm$E#\x015%\x02'
        b'\xf4\xc1\x1e\xc6n0\x9f5\xb5\xd3\xc7\xb3s1C\x10C\xf2\xd4\xd1\xd6a\xe6\xc8;\xf8t\xea\x9e|\xc8x\x8f\x80@\x7f`\xcf\xf1\xa6C\xc5\xb7\x8dD\x10>\x91\xf8\xaa\xdf\xb1\xf0\xec\xb5_\xa5\xf1C\x01+\x1c\x83\xe9'
        b"n\x8a\xe1'MBW\x04\xa8z\xa7[\xa2\xd4k\xe7\x9d\x9c\x89\xc3It3\x91\x85\xbc\x99\xbb\ngg\xe9\xef9\x91\xf2\xfe\xc8o\xe5\x07\xed\xb8\xa0\xcb\x874U\xe9\xf8pp\xeb\x99x\r\xf1\xcd\xb0\xc3)t\x8b\n"
        b"\xa7\xec'>L\x04\xac\xd9\xd9z\xc0\x08C\x16\x90\xee\xcf\x02L<\x92\xd6Qtx\x98\x82\x8a\xb0%:\x15\xca\x1fF\x13\x8d\x18fe\xaf\xe7p2\x02`X\x0e\xcf\xbd$p&\xd3\xf0Z\r\xe9\xae\x0eH\xb7\xc8\x8f"
        b'\x12\x1d\x18dl\xf1\xad\xe5I\xe4\xe6\x1bR\xd7\x1fU@\xec\x0f\xf8\xbb\xaf\xa2\xbd\x95j\x90\xe5j\xc4\x91\xcf\x0b\xfd\xe41\x13P9X+\x81S\xe5\xb0u~tS\xda\x11l\x84a\x1c\x11\x91\xe5\x9b\xe7\xa9\xbd%\x8c'
        b' \xb0\xb3\xbd\xabA\xd5Tp\x0b@\x1f]\xa3\x0e\xb3/\xefQ6l\x85\xc9\x15\x0e\x86z\xde\x13\x08x\xce\xff\xb0\x0c\x8e\xcfO(\x01\xff7\x83\x9d\xee\xe9\xebm\x16np\xa4\x13-\x05E:\xf5\xf4\xe1\xa8\xc5\xd8I'
        b'Y\xd0\xda\xbe\xa3_V\xdf\xc7\x9c\xb57\xf3VDSw\xc7\x07\xcc\xf8\x9f\x13"\x1c\xe1\x1aR\xff\xfd\xff@i\x1f\x9c|H\x984\xac\xe4<\x04\xc5k\xdab\x06\xd8\xbf\xebf\x97\xa3Eo\x02A\xb7\xfb\xe0q\xa8>'
        b'\xbf\x81i\x9dR\xfa\xfa\xbd>)\x13\x16\xeb\xfa\xabG\x8b\x85q\\\x0c\x80\xd7ggVH\x00\xeb^\xdc\x80\xd8\xff\x9b\x9d8]\xbf\x9c1\xbd\xb9\xe1\t\xeb\x1beD\xd91=\xe77\xff\xf3R\xb1*\xbf\x8d{\x84\xa4'
        b'\xc2\x84;\x00\x19(p\xbf\xfe%\xe9\xf7\xaa\x1b\x8cG\x82\xed\xc7\x18\x9b*\x83\xe0J\xa6G\x94\x16\xab\xae\xed23\xdb\xe5g\x12\x0f\xd8\xe1\xd3y\xb5GuFK\xaf\xc0\n.\xff?\xee\xa90\xf3m2\xc1\xecP\x8c'
        b'\xb2q\x85(\x19}\x8a\xaf\xadP\xd49\x01\x16\xfa\xf2\xa5\xf8J\xc7\xe0\xa3j\xa1\xc6q\n\xa1\xb6\x94\xed\xa9\x92\xc9-p(\x85}b&\x01\x12-\x14\x077\xe3\x1d\\\x02\xaf\x0c\xaa\xfa\xc1\xff\x91y}\xe7\xd9!\xe9'
        b'\xf3\xe5=\xd7\xa2.\xd3\xb2\xeb\xfe\x95G\x8b\xb2D\xa3\x86\x88\xd1\xa1\x90\xb0\xd0\x02\x08\xcdr6\xa9r\xd4\xe0\x1c\xfaI\xec\x8a\xbd\xf8im\x9d\xbf\xdf\x06\x028\x95|\xcc\xac\x84To\x9f\x13f\xa4r\xaa\xb5H\x01f'
        b'\x8f\x02\xcea>g|z;\x95\x9f\xe7T]\x02>\xc4\x85\x95y3\xe9\xb4\xa6\x120V\xf4\xc8\xb2\xb6\xe0\x08\x96\xc5\x13P?4\x93\xe6\x19\xdc\xf4\x9c\xe1\xe0\xf40\x80.\xe1@n\x7fw]q\xb8\x96:\x03\xcd='
        b'1\x08J\xf1\xfa\xbe\xb8A_\x9f!\xdaMu\x9a\xc0\xe9\xaenP4\x9f\x10%\x8e\x15ak1\xde\x17\xba\x18\xb2\xc3\xf8\x87\x01\xfa\x1c\xf6\x96\xed\xef4\x18@v\xc4\xad\xa6\xb2\xe1\xc5;wI-:\x99\x1a\x828\xc5'
        b'=\x19eE= \xc3.4\xad\xb9\xd4\xcc\xad\x17\xbb\xc5~\xc2B\xf9\xaa\xdb\xb5\xd80\xda\xd7\xd5\x9bJ\xf71\xf3q\xba\xb2P\xf1\x19\x8d\xa9R\xc0\xe3\xda\x14\xeb\xa2\xf4\xc9\xbe\x0c\x1b\xf5\xf1\xd4\x82\xd8\r\xe6\x15\x01M'
        b's\x9eZ\t\xd0\xd1\x06\xdd\x11\xd0\x0c\xfe[\xbe\xe3&\x95\xd7\xdf\xacIt{\xc5\xe1\xfc\x94\\\xa0\xe5N\xf8\xb5\xcf\xd2Q\xef\x03+\xb4\xc5\xb8\x13E\xccYE\x14\xdb\xdd|\x89\xfb\x8b\xdel\xd7\xb5\xda.\\%DN'
        b'M:?L\xc3G\xff\xb8\xfbxc\xce,\xa7E\x1aO\x95\xfa,\x17\xda\x89\x1fw\xbd}"\xa5\x95\xac\xddc\x95F\xaa\xb2Z!}\x8en!q\xe1\x13j\x0c\x0b\xe0=\xb1\xf9\x17o\xea|\xa1U\x1d\x0c\x80\x9b\x96'
        b'v\xbb\xa3*\xb1\xb0te\xef0\xf4\xf6a\xc2Co\xb1\xe0\x1cp\nb\xf1\xe9R\xe7\r\x0b\xc9\xab\x97\xe3\x08_\xa9\x8b\xf5\xc3K\x1e\xb44mc"\x08"\xf9(\x14\xbd*\xd9?\xab_<\xbe>\xfe\x1e\xee\x02['
        b'\xdbU\x92\x08\xff\xe6\x9d`\t\x18\xc6Yj\xe7:\x04\xabZ\xee\xd9\x1c\xc5\xb7s\x93\x9c\x00\xaf\x9b.\xf2\x97Qoh.*\xfb\xa7\xc1F\x91\xa2\x97\xf1\xb5\xd6:4a\x7f\x86E\xf4\xb8\x1cg\x8bi\x11\xce\x98-\xbb'
        b'\x10\xa0D[\xc3\x87m\xe7ZZ\xcc#&\xb7Cm\x8b\xcd\xf5\x12v5\xbb"Ga\x91\x0bGk\xf9\x1c\x05\x86,X\xd6\x028\xab\x8e3\x83OX\x1e\xfdgB\x81\x0c\x03\x93J\xed\xb0\xa7~9\x93\x8e\x08\x16\xb5'
        b'p\xe2\xf2\xfeN\x8e\xf9\xc7%X\x92\xab\xf5?M/g\x0b\x0f\xd0a4\xf9\\\xbb\x15\xf7\xd6\xd3\x84\x14x6\x18\xbb\xf9\xedm\xc7^\xea7H\x8f\x9e\xa5\x14\x92\xb2\xbd$\x00o\xf4\xb8\xb36\x95\xdf\x0fC\xff\x1dL'
        b"D\x83\xd6c\x8e\x9dl\xfe\x9b@WL=<\xe2\xce\xa9\xd6:\x1e u7l9\xa2\x9et\x9a\xc39\xd4\x92\x137\xc7K>\x7f\xec\x1d/\xa02'\x11\x15\xc1\xa4\x01\xa6N\xea\x87\x19\xe1\x10\x93$\xb5k\xdf\x89\x97"
        b'\xd1$Q\x0f\x99\x10\xb1\x1a\x9a\xbb\xa4\x88\xbb\xf8jg\xe21\x01\xbd\x12\xf0)*\x165<\xd0\xd3\xb1\x17U\x80i\x86\x87\x8e\xbf\xf2cm\xea\xe8\xc5B\xf0\xa7\x0e[\x12\xf9Qn\x1f\xf0V\xc7\x02\x90P\xb5\xe2B\xd9'
        b'm\x8a\x92A\x95\xf3\xa4\xacN\xbf\xe0B\xea\x9c\xe7.\xefK\xb3\xff\xccY\xc5>\x01\xb9n\xd3\xa5;Y\xf12`3\xe4\x07\x1c)\x92\xd6\xeacvI\xeec\xe2\xe6^\x9c\x10\xc7\x11\xc3\xfc\xc2\x7f\xd2\xc7\xc6J\x03\x0e'
        b'\xe6\x9c\xf8\x98d\x94V\xde4\xb0\x183\x11j\xf1\xe0\x92\x81\x91\xedB\xac\xb3a\xca\xc9\xa9\xbe\x80\x98\x1e\xb8e\xa3\x01c\x1d\x85-\xd1\xb9=\xeb\xe0Zjz0\x1e\x156k\x9a\xccO\x9dC\xf9\x88\x0ciJ6\x8e'
        b'\xc0\xf4s3|\xca)\x80<\x02b\xeeb\xc1d\xed\tx\x1f\x99\xb0\xe4"\xde\xf5\xc0\x9a\xf9(#S\xf8\x87/\xf7}\xb8i\xd0\x84hW\x93\xd1\xfeGAz\xe0\xb0y\xdf2\xca\xc4D\x1ckD\x81\xa2]\xa2\xf3'
        b'U\xef\xffJ_\xf7\xc8\xb8s\xd6\nG7^\xb5\xc0\x8a\xfb<\xd9\x80\x87x\x01R\x05\xee"\xf8\x01\x96HZE\\my.\x97\xa7\xad.\x15\x99Q\xdcN\xc9\'\x1e\x87\x172\xf96\xfd)@\x93\xd5\xc6(\xb7\xe3'
        b'\xddi\xea9\xb0,\xde"\x84a\x87\x8b9\x0c\xd5\x08\xcb>\xbe\x89B\x81\xce\xcd\x9c\x17\x82\xc4v\xa9-\x1f\xcd\xdd\x96\xf1\xf7%\x0b\xc5V\'\xc8\xbbu\x1f\xfa\xd24\xf2\x89\xda\x04\x17\x99\x9c\xca\xaa\xf9\x99\xe1\xc3\x07P'
        b'6%\xe0\x98\xf7\x19\xda8\\\x83"R\xdb\xd0L\x8e\xee\xfe\r\x13\x8bq\x8f\x9d\xc3 \xf2\x1e \xa4\xe8J\xa9\x9e@\x0c\xdfQGT\xebnO\xbaEY\xca"\x91\xeb\x1f\x95VJ\x90\x9c\xa4\xc7\x92\xd4x\x85\xef\xd8'
        b'@\xb3\x13\x8b\xbd\x1d\xeas`c\x14\xd3\x1e\x07<_\xbe8v\x1bN\x88\x99\x18}. 7G\xbf\xc7\xb9\r\x00I\xc6\x1b\xe6\x03\x81\x0fKw\xda\xb6\xee\xa43~I`\xb9\xe3\x9c\xf1l\xc9h\xb3<\xcb\xab\x1e\xf6'
        b'\xd4o\x1e\xfeZ.z7g\xd2\x83\x1f<\x86\xa3h\x14c\xa3 \x86DU\xfajxd\x7f\xb8\x9b\x15\x0f\xd1\x02\xc4*\xcd\xc5\x1f\xeb\x14*3\xee\x99\xb3\x10\td\x7f\xb2&\x0b\xc4Pz\x15\x93+m\tZ\x80\xc0'
        b"\xad>\xaf\rZV\x1a\x1dC\xc0H\x139\xeaGZ\xa6\xdd\xe8\xcbh\xfd\x95\x92\xc83\x98K.\x88\x92'\x93\xc3f\xbb\x88\xb8E?\xfa\x8f\xc29Rb92\x88\x1d\x83ZI\xbc[\xf5P\x89\xe0)l\x96\xa4="
        b'P\x03\xc1h\xbd\xdcv\x1e\xb3\xe5\x9d#\xe2\xe0\xd5\xac\x00\xe7\xfa\x7f\xc4\xa0\xd1q\xcd\xb2\xd9sl\xcf\xa08\x1e\xf5j\xc6 \x7f)\xedv\x80\xd0\xb7\x97\xf9q@\xd1=\xef\x8eI\x83\x85\xc2\xa3\x97X\x9blI\xa5_'
        b'su\xca\xa5\xcfB\x18\xcfB\xa0U\x17_\ra\xee\x1dw\xee\xb3#\xc7\xe1_\x88l\x9f\t-\x15\xa2\xed@\xb7\xaa6g\xea\x8c[\x81\xa5O\xbb%\x822\x8cZ\xdc\xd5j\x19!7\xce2\xb1\xf5\x00\xf8\x08\xafU'
        b'\xdb\x95\xa4\xfb\xfb\xc0\x1f\x9eD\x1c\x90\xdc,\xe0q\xf7\x8b\xa6\xdco\x1e\xb9\xdb\xd6\x86\xa4\xa4\xdd\x96\xdc\xc8\xad\x9f\x93Oic\x06u\x01\x16\x9e\\\xe1\x8e<I\xa4K\xc1E\n|\x0b)<1\xa3\r\xe8\x05e\x9a\x7f'
        b"%J\xed\xe6&\x139\xd9\xf5w\xaf\xd7\x13\x039ZJ\xc3E\x08\x00\x8e\x01\x18\xf8\x94\x7f\xf1\xd56=m\xac+e\x8b\xa2\x88\x94\xac\x15\x13\x85\x01\xd9\xe4\x9f\x1ei'\xba\x1e\x1fx'\xa7&A\x82\x81Aj[\x7f"
        b'\x0c\xc6\xd4\xf2Z9\xc8\xeb\xf8z\xb2\x1f5nk5\x1f\x95\xc9\xfeC\x1a\xdf\xb3\xc0&\xf0\xd5>F\x16\x8fN\xc1"\xb9\xffw\x11\xaf\xb0zk\xcc\t6\xd8\x96\xf8\xf9\xa6\xc8\xf2\x9fb\xcd+\xa1g\x17\xebPB\x05'
        b"\xe7\x847\x044\xc6\xef\xcd\xfa[\xe4='\xa8\x03b\xd5\x93\x14\x9c\xdb8\x85\xc30a\xe73\x1c\xd5\xa1\xe5b\xf8Nv\xba~Qw\x93\x8b\xa4z\x1a\x03\xcd\xc6\xa1\x1au\x9bq\xe0\x83\xe3\x04VP\xbe\t\xdc\xff:"
        b"\x82\x99p\xcf\xe2\x82\xa1s\x18\x18\xd5Ft0\xb7m{{\xc0R\xa5\xc5\xa9J\xc7\xba\xc8\xeerB\xaf\x81\x9a\x95!c5p\x0f\xdd\xef\x9d\xff\xb3w,\xe1\x9df'\xd1\x9f\xe1\xd3i\xb1\xa0\xda\xaeg\xe9\x91{,"
        b'\xce\xfa\xa0*2\x0e\xec\xaf\x9cw\xde\x88\xd0`\x96\x17\xf2\xdc\xcc\x02\xa17%\xe9\xee\xdd\x9f#\xea^K\xb2\x85\xa4vA\xd0-\xe1\n\xe2\\\xd31\xaf\xa7O\xd2\x1e\xf7\xc2\xe7\x11\x16\x96-\xad\xee\xb2\xfeY\xf0\xb7\xd3'
        b'\xde9\xcf\x15\xc1v}\xe7\xf1\x946\xd4\xff\xf1\xb9H.\x08\xa5\xd3\xb9,\xa3L\xf3z^0\xf1\xa3\xf0?e\xc47d\x94\x08\xfbh\x18\xd9\xa7\xa2`\r(\xec\xb3jB\nbT)\x8e\x08K\x082\xc3\\8\xe1'
        b'e\xf4\xa0\x1c~\x86u\xfe\xe8\xbc\x16Cn\xaf\x00\x98\x86\xa4U.e\xdeN\xa8\xff\x06\x13\xcc\x89@\xb7Tg\x98\x92g5%\x80\x97\x92\x05D\xbc\x156\xaf\x0f\x01\xad\x17)\xa0\xb7\xeb\xe7\x1d4\xc4?\xce\xe0\xb3p'
        b"X\xa5-\x0b\xe2\x9c\xf6k\xbf\xecT\xca\x7f\xf5Y{\xa7\x93wx\x00\x175\x8eA\x88\xa3\x1f\x83\x892\xad[,\xdc\n\xa6u\xbf\x0e\xf6\x8e\x1b\x86\xd3'\x88L\xa7w\x16U\x1byl\xa6h\x0e\xc5\xe1xo\x8d\xee"
        b'\xd7\xfa\xbb\xed\xfa\x04\xe7\x16K\\\xde)\xfc\xd2U\xf4\xec>\x7f\xbbS\t\x9f\xca\xb3\xdb\x14\x91o\xd3\x9f\x01A\x8e[j\xd8}\xbd\xaek\x0f\xdb\x01:\x02\xec\x126\x0b\x90j\xe5\xd3\x0462$\x0c\xa4XB\xad\x96'
        b'\xdfY\xd8\x06\x9btj\x0cX\xe5;\x98\x003\xdd6\xb6h\xda\x04\xad"\xd6\xcc\x98\xa0\x02\x1f\xac82g\xe4QG\xb6\x93\x1b>\xba\xb5R\x0c\x91\x91$\xb5\xbc\x05\xdb\']\x97\xa3]\xaf\xc5\xfa(\x15nYk\xfa'
        b'\xda=m^\x8e\xbf5\xfe \xdbR\xa8\x96\x16\x9er\xda\xd8`\x13RA\xce\xb8#\xc0?\x8b\x84L\xab\xa6%\x92\xaf\x8d\xd8M\x9d\x19E\xff\xc8\xef\x92\xf9a\x082\xd3\xef\xa8\x12J\xd8\x89\x18\xd7\xf4\xaf\xcb\xc2\xe4\xfe'
        b'R~\x1c\xf6o\xa3\x87\x1d3.]z\xcf\xa0\x03|\xcf\\\x1bw\x10\xe5\xbb\xf56\xb8A\x172\xf8\xd0 \x1a\xce\x89\xd0\xb2nEW6\xdb\xcd>J\x1e!(\x17\xbf\x18;\x88\xfc0\xb3_;Sp\xe3\xb2,n'
        b':\x17Oex\x17]9|/\x94\x12\x9d\x035\x9an\xc9\x9ai\x9e~rG\xb7;\t\xd5NM\xc6w\xe1U\x17E\xbc\x155\xec\x13\xd9Y\xcc\x00\xec/\x9d\xcb\xd3\xa0t\x13n\xfc\x91U\xaf\x99;\x13\xaeb\xb4'
        b'\x10\xb0HU\xba\x97K\r\r\x18l]Tu\xba\xb2\xcf\x91\xa8\xaa\xe0xI\xb1>P\x08\x0bq\x18s?\xac\x05\xc2@\x14\x11\xa5:i\x0bT%\xc7\x16\x9e\xcb~[`%\x18\xb5\x0bd\xe0\x94\xf9Fn\xcb\x95\\'
        b'Q,\xef\xa9\xef\x92A\xc1\x1f0\xfc\xb2\xb0{\nL\xe3Cn8Y\x19\xc1\xe8\xec\x01\x1a:\xea\xfc\xd7\x1d\x1dW\xe7\xebO\xb7\xaf-\xacYp\xfe\x00\xc1\x1b\x88!\xca\xdfy\xef\xd7+\xee\xe5\xb3\x8e\xb9\xe6\xac\xc4\x11'
        b'\xfa\xce\x16{21\xd35g\xfc\xc7\x92\xf6l9_.\xac/&\xea2\xef]-fi\xed\xd2l\xed\x97\xc6\xbb\xd6$\x8d\xc8\x82\xfak<\x90\xd3\xb9C/MRD\xf6\x90\x85\x00/\x9c\xe5\xa3\x8bi\xa6\xc5\x0bz'
        b'-9{\x1c4\x80!\x99\x04\xf4: \xf9\x14EAin\x14LMn\xc6\x8e\xc8%\xf0p\x9fnhb\xde\x90\xb4\x81\x0b\xc7\x11\x04v[\x04\xd0\rL\x9a\x14X\x96\xcf\xb8\xbb\xc1\xc1V=\x0b\xd7 \x07\xc3XD'
        b"JNi\xec\xa9e\xe7:\x04\xe0\x15\xc7B\x8a\xfd\xb3o\x80f\x9eK\xc87:\x0f\x96\xef\xb2\xd0\xb4J$\xb3\xf1\x1cc\xc2{n\x85!\x82i\xb3\xe5\xc4\xfcPX\x1c\x91\xce\x11\x98m\xf6\xa8\xe7\xc9\xc1S' \x82"
        b"&wg\\\xb0\x87\xaa\x9a\x94\x9f\xb2\xd0\xee\xd8\x8d\xe5s\x0f\xbc\xafBD'qi\xd0\xe4\xabb\xa8\x8dz\t/\xe9\xc8\x90S\x8a\x94|E\x07\xa5N\x93vR>\xc48VtI\xb2\xe1*\xca\xb0\xe2_\xed\x891"
        b'\xa1#\xceT\xbe\x8b\x1b`\xcd\xad\xe6\xcfci\xc01\t1\xe7\xbc\x13\x04\x02R\x8c#\x96\xcf\xa5\xaa`0\xc9\xdc\x14\x0c\x11%6\xdd\xf1M<\x15\xbc\x99\xcau\xfa\x0c\x02\xa5\xda\x99&\xfdB\xcfT\x04\xfa\xa3\xb6\x83'
        b'Y\x02\xbe\x91<H\x06v\x13\x1e\xf2]\x85N\xd5j9\x15\xae`\x879\x8d\xdd\x03=\x11\xe4Q\xd4\xe0\x9a\x96\xe49\x19\x08\x02h\xfe\xa5q\xca8\xd9\x8f\xd7T\xc8R^\xa9\xc12\xfd\xae\x934\x9d\xc4\x15\x7f\xc6F'
        b'j\xa4\xe7P\x18H\x06U\xbb\xb9I\xfd4\x9e\x8c\xf3\xb99*\xab\xe3\xf13\x97\xee\xec`\xc9R`\x80\n\xd3\x15B\xa1\x82\xc9\xf0\xa4^\xcf\xb6SP\x9f\xb0[\x0c\xc0"Z\xaf\x02\xcd\xd5\x80\xb6U\x92O\x00\x12\xc0'
        b"P\xc5U\xf1\xe3\xd4\xe3\x92%\xd7t\x05\xdb\x05<\x06}\x9a`P\x8b<8\x0eY\xa6\xe4\xa4)R\x8d\x96\xcf\x1b\xba|\xcdU\xed\x00\xd3\xd1\x97Z\xdc6\xabX\xeb 1\x00[\x0fP~\xbcH\xbc'\xb0N\x98\xd5"
        b'\xf8\xd2J\xb8\xb7\xa0`\xb8Z\xa1\xefz \xf7\xd7\x85\xf7\x05O\x83\xf85\xbb\xaf\xe3\xe0\x99\xa7\xfc\x11\x1f\xe1M\xb4.w\x12[q\xcc:\xf7\x1f;\xb6\xa1\xc1IGr \x8d\xdej[%\x9b}\x9d\xfd\x8e\xb1\xef"'
        b"\x14\x95'\xb4\x9bH\xce\xf1\xd4\xa0\x85\x80S+U~\xbd!2\xd3\x07\\\x91\xc1VU\x03\xa8\x95\x13\xc2[\xf4\xa9\xed\x00\xf3BGB\x91_\xa4*\xc6b\xb1\xf0\x82\xbf\xad\xf7\xe6:@\xbb\x1d1[\xb3y(\x17_"
        b"W\xec\xf4\x91\xaa\xfd\x00\xe0\xa6\xfa\xdd)\x05_R<\xa9J\x13\xc7'R\xcbm\x86\xd9\xa5\x80b\x8dv\xae\xbb8\xca\xca\xc7\n\xa2\x8c\nki\xb7\xea\x18:\x93A\x98\xe4\x16R\xa3cnJl\xe4\xc6\xbd,~\xd5"
        b'\xcd\xee\x7fr\x83\xdbO;\x85t\xfd\xf0^\xd4,\xf1\xf9\xc9\xcb\x99\x93\t$\\\xa7v\x909rF\xbdl\xd5\xaeN\xd2\x00_=\x86\x90\x8c\xd3\xc3\xde8\xcf\xc6\xab\x00pl\xc6\xeb;\xf92@\x821?e\x86\xc0'
        b'.\xaeS\x91\\\xc8BO\xe60\xd5\x11\xee\xbd\xdf\xe3\x8f\xebGL\x02_\xa0\x9e\x8e\x15\xe7\xe7\x9c V\xe8\x97\xb9\x99\xa0A"\xd9;|\x02\xcd\xa7\xd6.\xbd"\x8b\xfd+\x04\xac\xfat\x1e\x9e\xc1\x07\x04;8\t\xc5'
        b'\x04\'Y\xd1T<\x19@\xd0]\x98:\xe9\x82\xea\x9d\xe1ym\x12|\x1cf\xa8c\x8d\xb0\x82\x04Y|[#0\x9bQ\xbc@\xc0\xa0\xd7j\xea\xc8\x8f\x92\xb5\xec\xff\x9c\xa6\xab|\x08\x15\x85.x0,\xbb"\x9b='
        b'm\x03\xed\x0c\t\x94\xde\xe3+J\xe5\x9dNYqj\xf7F\x89\xf2\xe9i\x0c\xb6\x17!\xbc\xa1\xd8\x00\x02\xae\xa2\x8fR&\x99\x18\xa3\x91\x9c"(FO`\x90*M2c\xdbi\xb0\xe3yHbE[\xf4\x1c\x0e\x81'
        b"\xf5P\xb8\x07\x10\x0b\xac\xfb\xc8\x86\xa6\x9ai\xdc\xa2?p\x83=\xe0\xe6n\xd3d*\x9a\x85\x01\xb1CO3*{\xc8\xfcR\x17p\xdd\t\xbeSg\x11F/\xa9Q\xf73'\x979%\x1e\x83\xb4\x92\xf8[\n\xb2\xec"
        b")\x9a\x9d\xa5]\x07\xa4\x16\xc8F\x8fZ\x13\xedf|}T\xe7\xab\xb4\xd4\xafp[\x10\xa9\xf7\xdc\x93X\xbb'k\x06\x87q\xf0x\x0b33\xe6\n0\x92\x06X\xd7\x8d\xf9\xc1\x15cpKm\x18\x7f\x01o\x91)%"
        b':h\x19WY\x99\xc7\x96\x85\xc70J\xef\xdeq\x95\x1e\x99G\xcd]J\xdd\xe6\xee\xf9\x9d&\x8a\x80@jw\xa1\x98+\x8c\xac(;\xf2\xbc\x848\xe3\x86\xe2\xd1\xcdg\xa8DW\xc5m7\x98\xa0\x9c\r\xee\x82\xd1\x0f'
        b'\x1b\xb5u\xbcl\xa4:\n\x81\x90\xc1o\xfc\\$0\x08Uo\x0f\xd3\xcf\x00\x83\x01O\xb1\x1bXA\xf8\xf4\x03[\xaa\x9aP\xfa\x1co>\xe9\xc1M\xcd\x8bb\x86\xc2y\x1e\x146\xf7\xd0\x0f7n\xad\x86\x8e\x0e\x89\xa1'
        b'\xa2\x01+\x9f-\x14\xa6d\xc6`Gy\x8ar8\xd8\xd6\xce\xcc\xa7\xeb\x9a1h\xb4\\\xef\x02/R\xd7}2\xaf\x1c\x18\xd5\xa1\x86\x06\xaeHr\xfe/8\xc6\x7f\r\x11s\xf0\x8f\x96{\xd9F\x98=a\xe1\xedH\xb9'
        b"p.X\xc3\xa7\x1d\xe9\x06\xbaF\xb0\x004J~\xf2\x02\xdb\x04\xd4\xef\x8a;2S\xefy\xc9'\x1cHo@\xc1\x8d\xb27P\xe4,5\xcd\xcdk\x12QX\xd0D\x8b/\x02\xed]\xab'\x9a\x0c~O\xe9\x1c\xff\x01"
        b'\x95@v2\xa2u\x08\xba\n.\xdd\xf9\x9c\x85\xf5\xb4\xef\x96G\xcc\x0c\xb0\xf7\x9d(\xee\xf2|\xf6X\xc4\xe6,\x03>j\xb8\x8b\xd3w\x8a\xcd\xa8\xcc\xe6\x1d\xaaj\x8e!9\xd4f\xf0>\xf5u}\x0f\xf41\xfb_\x1f'
        b"#\x9f\xd4\x04\xd0'\x86\xb3\xcc\x0f\xa0\xaf/\x03\x99\x82I\x80\xe7^\xbe\xce\x0f3fF\x0e\x01\xe3\xd6:Ej\xa7\xf5\xeag\x8bk\x17a\xdb\x0bn\x10C\xf2v\xbe\xcd_\xef\xb5\xc1\xa4_\xd0:\x1e\x86\xb2\x97=\xf1"
        b"91/x\x1bG\xfaSl\xaf\x8c\xc6r\xb3\x85zUm_KE\xf4\xda\x93u\xb05h\xb8\xa3}\x95\xb6\x1a\x04\xf8\x0c\x83\xbaH\x82a\xf0\xdd'b\x95\x88\xd01\x14\xb2\x86\x1a\xec\x87\xc9\x0b#.\xc3\xfd2\r"
        b'0\x15\x19~\x86YG\xa3\xf920\xca\x0eD\t\x86\xeep\xfb\xf1\xc5\xeaI\x80\x159:5\xdd\xe8^na\xc7e6~\xf7\xef\xa4\x08{\xac\xda\x03\x1e<p\\$\xe9z\xb8#>\x95?\xf4\x9c*\xa2\x021\xb8'
        b'\r\x7f\x0e56\xc10q\xcf\x81\xf0\xad\x9ciT\xe0\xaa\x90\xf8\xb1\x1b\xfeTv\xba\xdb\x94m\xf0\x83\xb0!\xc6K\x80\xb8$\xd3\x88\xf0\x06(!*K\xc9D\x05\x1e6\xd4\x91 \xfd5\x94\x12\xc40\xcbs\xed\x9b;'
        b'\xd6u$\xfe\xe6\xc0\xbdJh\xe1\x91\xb8\xd5lQ\x16\x12\xaeq5\xa8\xb2\xf1\n\xe5>\xbc\xe7:\x14Jb\x94\xc4\xc3\xca\xc8+\x9c\xd6\xc3\xf9\xb2\x16\xd9<v\x15\xab\x81\xcc\xf2\xddrk/\x96\xc1%&\xcd\\\xd35'
        b"\xe0_=![\xeb\x05\xd5\xcd\xf6\xa0\xd3\x12\x92n\x15i\x89\xddS\x8c\xbf\xc4\xe8\xe7\x01\xf1\x8a\x19\xa8\xb9\x04+*\x9b \xcb\x8f\x91\xc2\n8,\xb3\xb43\x95\xabWtW\xa0^\xbe'\xffX\xf2\xcfE\xea=\xe6="
        b'x\xdc\x13\xa4\x8d6Yjo\xbb<\x11\xa6(\xc1\x9c<\x0c\xdf\xf1\xfe\x81\x0c\x8a\xec\x13Vs\x8a\xf3\x85\x8a\x8c7.\r\xfe\x02\xf2)\xa5\x13\x0fi\x18\xf3\xc8)F\xd6\xa2\x16\xcc\x93{\x00\x99\xd5\xd5\xe5\xde\x0f^\x14'
        b'\xe9\x90\xc5\\`\x97\x1b\xf1C3\xae\x9cd\t\x94>\x87\xf4\x810\xeej\xda^\x0f\xdd\xcf\xf0\xa62\xd5\xb1!\xcbT.\x90<\x96|Q\xdf\xefhA\xfaxL\xd4\xc4!\xf2\xbe1\xa7\x83<\n3{\xafG\xe6>'
        b'\xa4\x8f\xe8NL9F5\xfa\x02$\x1e\xd0\x90\xa5-\xc0\xb5\xa5\x1e\x8e\r\xdf\xcfMW[`\x8eG\xba\n\xaai\x91s\xea\xe3x\xf5M\xe7\xed6\r\x92\x95\xb9\xe3w\x15\xfcRK\xbd\xbb\x16\x18\xf7\x9dse\xd6\xcb'
        b'fD\x03R\xaeH\t%\xdf\x0c\xd5\xd2\xfb\xda\xe6\xb9\x94S\x06\x14\xec\xbb\x9d\x8ds\xc3\xb9&\xa0\xf6L\xf3\xd5\x9f\xe74\xc4Da\x0b\xb1\xd4\xa2\xef\xf3\xbd\xbc\xd9\xaa\x1c\xa0\x8e\x04\x9b\x12\xd0\xd1\r&S\xef\xaaQ\xf2'
        b'\xa9\x19\xbd"\xa7\xcf\x91\x94$V\x03\x9f\x8d\x077\\\x9e\xdb\x9bp\xa3\x01\xdc\xa1\ns\xab\xbc\xb4M\xd5M\xec\x85\x94\xdaB\xe1\xcb\x8a\xa1\xa8?\xac\x05\xd2O\xb5oyhu\xba\x9d3\xfe\xe2b\\1\x81\x1f\xb9%'
        b'PB\xa3\x0f\x00\x88\xe6\xb9\xa1,\xb2\x91\x14\xc3\xe3\xa0 ,\xbd\xb3\x91\x89\xd4\xa0\x1e\xe5\xfb\x02\xb5W\xd5\xc6\xab\x08\x91\x10\x94\xe6o\xc32\x01\xdc\xbctxq\x81\xcc[\x0f*s\x1e\xd82\xb9H\xe5~\xda\xefh\xd2'
        b'\xb5Rc\xec\xbc\xd6\x8a\x14\x06\x14\x94\xd2\xbe\x10\xe7P$\xebd\xc8K"o&\x99.3Uoz\xfeF\xa9}\x0f\x11\n\xad\t\xfd\x85\x88\nA\x0b\xb2I`\xc2pb\x99E\x87s\x86\xab\x04^\x1b\xa7\x9cth'
        b'C\x0c\xd5*\x89\xee\x15C0\xd9\xc3\x14{\xa8t\x04KQ\xd6\x10\x16hJ\x03\xfb\x02\xb2\xe5#\x9f\x11\x9f\xfaKw\x028\x8f,\x15T\x90\xfc3\x1e\x874\x1bJ\xe4\x82\xe1J\xe5\x1b\x88[\x98\xfa\xc0 \x94\xe9\x7f'
        b'\xda\xe3*\xbb\rFpsj\xa2\xdd\xce\x1eOXN\x1d\xe3\xa2\x9d/(\x95vHV<\xf4\\\xc7\xf3\xf9\xd0\x95\xdd\xc0\xcb\x86d\x14\x16\x89\xc5\x8bE\x9a\xf9C6#z\xd8 .i\xda\xaa~\xaa9\xde\xc8\x95\xe3'
        b'\x0e<\xd2\xd2\x91\x92\xbf\x9eM\x0e\x0b\x05\xe0\xac\xff\n/\x9b\xe7\xdf9r\x15\xd6K\xd3f\xd5\x0eg*\xb7\x17$KUz\xa2#3\xd7\xde\xaf\xe4\xfb\xc0+\xa9w\xc9l~6U\xfb\x8c\x17\x1f\x8e\x8b\xa7\xd2\xe4\x85'
        b'\xd4\xce\xd0+\xbeo\xf1u0\x11\xd9T\xb7\xe2\xe3\xd2+\x88\xff~y&\xa8\x117_b\xf4>\x0b \xd6\xbe\x13\xdb\n\xafPf\x83d|\x16k3\x0c\xc5!p&\x12\x83.\x83\x17>\xcdZ\xbc\x82\xb4\xb14:'
        b'"\xbf|[S\xa2\x85_\x17\xaf\xe6\x89\x923W\xa4\xb0\xcdl\xda\xd3\xe9\x80\xc0\\"\xf9\xb8fc5<\xfe\xa8\xa8g/\x85K\x97k\xe7\xb9\n\xbfl2\xab\xbc\xa7\x97f\x99\xd1u\x85UM \x8eA\x04\xf4\x98'
        b'-\xfc\x83P\x00V\xaaFe\xec\xd60\xe5>XV\xfcD\xcb.KO\xa7\xb6\xb0\xf46\x96F\xc7\xdc\xa5\x17`\x0b)\xe6\rkPJ\xeb\x87\xdf\x0eq\r=\x11Q\xcd\x07\x8f\xdb\xb9I<\xcf\x0ct2\xd6"\xae'
        b'^y\xdc#f\xb0z\xc1\xa4\x9b@\x0eL\xd42\xd7\xfc\xc4\xe0\x16\x894\xbc\x02\x93\x08EuO\x0ff\xc5\x932\x98\x81=\x9b\xc2x\xab\x8c\t%\x9a\xa1\x82\x9dd\xf1\xed0\xbf\xd2\x91\xfd\x92\x0f\xf1\x11\x97\xcf\xc5@'
        b'\xcf\xd5\x9ao\xfe\xc5\n\x0c\xa9\x1b\xe4\x13Md\xcf\xa9\xae\x06\x0f5\xf1\xfe(3i\xa4\xb0>)P\xe3\x0e~\x7f\x1f\xe5M\xef\xef\xe6\x8f,\x8d\x9e\xf8\x9d/\xba\x84\x9e\xdc\xe4U\xe3\xe3\x83\xb1@,]\xbd\xb0\x8a\xa6'
        b'Vr\x072\xc5P\xac\x19\x1c\xe6-\x86\xaa\xf7\xcd\x14\x0e\xda*u\xee\xe6\xd2~i)U\xf3X6\xe9s\x18\x17\xc1\xefB\x8f\xc4\xa5\xd5\xdc\x10FU\xb5{\xc2\xf2\x07I\x02y\xe4\xbb\xa0\x18\xf3\x07\xf1HO/\x07'
        b'\x9f\xd1\xd7\xc4R\x84\x92\xf4\x82D\x0bk\xa7G/\xdf_B\xe7O\\\x98\xabx\xe6!@\xfd)I\x91\x8c\x9e\xcf\xa0\x0b%\rX\x9a\x1ck\xadV\xc67a\xe5\xda\xe1\xd1~\x93z[\xf4T\x9b\xd6\x0c\xfb6\xf9-'
        b'\xb3\x89\x84Y\xcaw\xdb\xbe\x1b\x80\xb1\xda\x12w\xbe\xebXx\xac!\xd8\xf8\xbcZ>U\x8c\x9f1\xb4\xfe\xfc\xadsB\x1fC\xb3\x16\x15\xdf\x07\x12-V\xba\xf4\xad\xb6\xd4\x1f\xd1\x10o\x91\xdc6$D\xb4P\x1a\x15\xb3'
        b'\x96\x8dK\xd9\xd4\xd5\xdaM\x83oC\xdf\x8b\xe9?\xeb5b\xa0\xdd!\xda\xef\xc5\xd0\xba\xb6\x14T\xe8\x8d0*\x9b\xcb\x85qpU\xf0\xf1\x8dO\xfeL\xa5X\xfdL\xeb\xd4)\xe8\x85\xb0ZS\x98\x93\xa9\xdc\xec\x1b\xa9'
        b'"\x8e\x92u\x00\x80\xf1\x13Sg\xfc6\xc3I\x17\xd0\xa53\x9b\x96\x17\x10\x84\xfa\x8d\x17\x99\xeb\x8chw\xba\xef@\xe7\xde\x91\x02"\x83\xa1\xb8\x9d\x0b\xee\x1a\xd0\xf3\x1c!`\x1d1\x04\x85\xe0|\xcb\xd3|\x18V\x19\xa5'
        b'\x8f\xd8T\x8f\x87sh\x8d]&\xbe\x10Y\xc0N\xd2\x95{\xa0T\xf5\x1e\xb1\xf7~=\xf0\x11\xd2,5\xa5CC1\xc3[+K\xef\x85\xb5"2\xe3\xfd\x85\x91\xf4b\xfc\xf8\x9d\xaf\xa2\xd1[\xe6C\xe1J@Am'
        b'\xe5\xd0\xb1\xb4\x1ca\x96\x15\xd5`\xea\x0e\x9fas\x01;\xe3\x03\x10;<u\xb32g\xe1|E\x98\tz\x7f\xfbw0\\3\xc4y\xed\xa7\x936Y\x8f\x19{\x99\x19d\xe2K[`\x0c\xfa\x85\x80\xa6b<\xa0\xcb'
        b"\x03(\xe84ES\xc63\x1e\x18\xf5\xe0\xb2\xd1N5\xc5\x8a\xaeX~\x85\xab\x8by\xb5\xd9\xca'\x9b\xa5\\\xcb=:m\xf4\x96F\x18h\x08k\xf0\xbe\x19\xe0\x98C5y\x8c\xc1\x06\xea*8\xbf\xbf\x02ga\xdeU"
        b"HR\x1ao\xfb\xf6\x8b\x1e\xb7\xfeH\xa6\xab\xa2\x82\x8c\x1b7I\xcb5\xd1'\xda\xad\xe81\xda\xb3O\xf2v}\xc0\x92\xa7\xb9\\\xbdG\xad\x8c\xdfx\xa5\xcc\xd2y\x14\xab\xf46\x9e\xcc&Nk\x8d~\xed_\x18B\xee"
        b"9YMm\xd2u\x05oo\x87\xfa\xfe\xc6\xe0\xe3-\xd0wh:\xaf#\xdc \xfe\x0e\x85\xd6N\xa6\x12G_'\xc3l\x14:\xbb\x84\xf2\xb1\xcb\x02\x81\x92\xa7)\x86X\xce\xda;\x9d~D\xd0\xd3\x08\xf2\x134\xc3\x95"
        b'\xd3\x9cf\xbb\x01<W<\x97\xef\x9a\xa3n\xdab\x89\xc5\xc8wU\xd6\x94\xbf\xf1\'\xb4\xf4\x1d\nw\xe1"\xfaH\x01\xa1|\xd2 Hs\xaafX2\xb3\xdd\xf8"wP\xd30\x03^\xcfW\x1c\x9dwY\xce\xf7v'
        b'Sh\n\xda\xa9\xd3\x91,~I\xa6\x82\xb9\x89z\xc4\xe4\xf5\x8e\xd1\xb6Y\x00\xee\x97\x10W\x02\x07P\xba\x9d\xb4\xbc\xb8\x81\x86\xfe\xf8\x1b\x88\x86\x0c\x9c\xf37)\xc6\xa1@I^\xd3\xc8\x84\xb6Kp\xe9\x1e\n\x92\xe6\xf1'
        b'\xf7=\xe4\x9dI\xcc\x9ah\x98\xbb\xd5\xa2%&\x06\xa1\xcf\xc5\xbfK\x12\x0e\xe1\xdd\xce\xfc\x18-\x00=\x0c\xf7\x03A[`\x0bo\x14\x03\xe8g&\x9ch\x0e\x03\x99\xea\xab\xe7\xe8\x0f,g\xfer\x07\xbb\x13\xe5\xc3\x16J'
        b'\x10\xb6\xc5\x1f\xec\xfa\xf8?\x0fX\xfbDc\xfbe\x1a"\xa2K7XZJ8\xb7\xdc]\xfc\x10\xa7\xf9\n`\xdd!y\x08`\x94\xdd"~\xacW]\xac\x96\xbe\xe9\x99w\xdf)\x94\x90\xf0\x10\xfa\xbd\xae>\xb7\xe4\''
        b'\xa9\xe5\x96\xbf!v\xd6\x94\xa5\x9c\xea\xa0f1\x92O\xec\xf1i\xed\xb5\xd80=h\xd0W\xbfw\x91\xba6\xc5\xb4&H=\xae9%"\x03\x92\xb9\xf7\x04~q\x84\xbd\\\x97\x97D\xad\x86\x9bpO\x0c\x82\xae\xc9\r'
        b"$\xb2\x18\xf0\x0f)+\x18\x1bS\x10p\xdc'u\x95\xe5\xa0\xce\xba\xc2>=\xa7\xe8^\xec\x03\x87\xc0\n\xf3W\xacjA\x81\xda\x19\xf0|e=\x9cY\xd8\xaf\x8c\x0fO\xfan\x86\x10\xb2\xb6)\xf4\xeaZ#V\x14\xfe"
        b'\xf2\x81\xb7vf\xefj\xa6\xca\x8e\x03\xe1;\x8f\xf9\x8e\x00BOT\xc4\x92uQ\xce^P\xfe\xdfA-\x13\x1e8\xb8\xffRy9\x85\xf4ewD\x1f\x13\xb6m\x8ee\x1e{\x1e\x16\x10\xb8\xbf\t\x0fE.\xedLa'
        b' \xf7_b\xe1\x1f\xf0"2\xb5\x82\xb1\x1d\xbb,\xf6\x0c\x9dh\x84\xac\xe1t\x1a\xc1i,H\xcd\xf0\xdaY0\x05\x8a\xc5t:\xe7\x8a7K&o\x7f\xc6\xd8\r\'\x156\xeej\xfb\xf4}Z\xcd\xddk\xc5S\xee\x96'
        b'f\xd3B\xcdWzGx\xfbm\x87{\x11\x95\xb5\xc7\xde\x15\xa7\x8c\x03\xc7\xe1\xae\x08\xd0\xd7S\x07\xc5ZZ\xac\x00\t\x96F/^#9\xe1s\x07\rS\x06z\xce\x10^\xa6\t\xe1\x97C\xee\x9e.nd<xt'
        b"f\xc2]Kq6\xad3z\xdeIP\xd2\x9a\x19\xce\r\xad3\x89^\xbcMK\xf5\xebSq\xc9\xf2\xa8\x04,\xbf\x9f\xa5\x8e0\xd5\xcdMs\xd9\xcc\xa2<'\xc7\x01\xbf\x87puG\xb5EM:~\x1e\x10Y\x8e\xc5"
        b'\xdcf]\xccy\x08F\xc3G\xe5\xd1\xc2\x89\x8f-!\x146\x84\xb2\x0f, \x13\x9a\xdf\x02z\xe0\xc6\x80k\xd4\xac=\xdd,\xac$\xb4_\xbd[\xec\xf2E\x85\x8c\xf9\x8d\x17*\x7f\x8b.[\xedq\xd8\xf7\xa8\x1a\xc6\xca'
        b'\x06\x8f\x8c\x9c\xf8.\xc4\t\xec\x0f\xac\xd8e\xc4\x831~6\x94W\x07\x00%\xca\x82\xab\x0eH\xa1E\x96\xd3\xf8t\xc69\x13\nt\xf0(\xd7yK\xb7\xb8O\x1a\x8d{H\xbbh\xb4\x93\xc8\x85\x1e\x8b\x11\xd4\xd0P\xa5'
        b'e\xaf5\x1e\xa1j\xcf.\xf5\x1foK\x9b\xe2\xcboiX\x86\xd1\xa8`\xf7\nGv\xc9\xfd\xf0\x98\x84\xff\x81\xda\xa0\xfa\xbc8\x84\x85\xed\xed:\xc5\x140\xa7\xcb\xa0}\xbdm \xf1zM\x9c\x90\xcd\xe7y\x93\xb7n'
        b'=\x89\xe0\x92I\xca)Xh\xd8s^\x9e\xfc\xa9\xee9\x8c0\xed\xc2\x9a\xee+Y\x15\xb3\xceo\x16\x99\x9aNZ\xd1\xa1\x00H\xf2i&5\xe9ko\x8at\x1dd\x8e\xc5=U\xd3P\xb8h5LA\xb3V\x1c\xb9'
        b'\x8cN\x86>mt\xff\xad\xfc]\xdc\x9f\xa6f\xe2\xc8\xe5.o\x99\x04;WkH8%grX=?\x16\xbf\xcb\xe9\xaby\x11?"B]\x90VY%\xa9\x97\xb2\xb59\xd2U\x1d\xaf\xa1\xa0+\x9fn\x1a\xd7U'
        b'\xa7@O\xc6\x0b\xfd\xa5\x80~\x93\x8a\xb2[\xac\xd3\x9b3\xfc\xf0.]\x8dS\x02\xe0\x88T\x96\xda\xa1\xa2 \xa8\x1e\xdf\xf1\xce#\x92=\x10\xd0F\xf4\x15\xfb\xb7\xd1Ed\x1e\x98k\xc7\x18\x0bO\x94\xb2\xe7\xae\xd9z\x92'
        b'\x1dy\x081\xd9\xf9J\xa3\x8f\xbf\xfb[\x92\x1fo6\xe7\xb4`wK(\xf1\x88\xe2\xee\xa5\xda\x04\xd3,\xedn\xefK\xac\xfa\xc2\xca\x87\x9em\x05P\xe2\x96\x0ep\xcf\x8a4\xb9Z\x7f\xc5\x1dP76y\xce\xc7p#'
        b"\xd6n \r9\tt\xa8.\x1f\xeb\xa3\x14\x05y\x81nK}#\x0b1\xa4\xfd\x08\x91k\xff\x95\xfd4\x08s\x96Z\xa3\x99\xe2\x12b\xbfm*\xff\x97\xeb\xd6\xc2\xe6x|-'Nw\x16\xc2\x84\x170\x85\xb9\x859"
        b"k\x9b3\xdc\xaf\x96\x19\xef\x95\xb6\x06]\xe4\xb5\x87\xf7{\xc2\x91A\xdc\xdc\xea\xa7\xccc\x96\xb9\xfb\xf42\xa6q5\xc0\x812\x97\xf4\x91\xf4\tf\xcc8\xf4\xb6'\xb7\xd3Kq\x92H\xe6\xe1\xe1\xe1\xaeCR\xab\nN"
        b'!IC\xdb\xa4\x03q\xdeK\xc9i\xd3\x8a|!z]\xcd\x03\xbf\x07\xc6[\xe8\n#\xcd\xc7\x13?\xcc\xb6\xc6\xd3\x11w\xf1\xaby\n\xf2\x1a\x87\xa9\xea\x06+uM\xe0CB\x80\x82\x86\xc4\xa3\x15\xba\xca\xd7\xbb\xfdk'
        b'\xc0r\xd3\xda\xc8x\xce\xe1pL6>q;\x93\xf3\x8d}c\xc9s\xe3I\xbe\xec\x05\xdb\xc24b&T\xd9\t|\xe2\xe4\xcbm\x8b\x08\xe0\x91\xad\xa4;\x18\x14\xd6\x99\xa3\xdb\x00\xc1+\xd5\x1a=r\xcfn\x96\xbf\xe7'
        b'_=\xf7\xdb\x9cX\xb5\xba\xa4Qx0\xfb\xf2\x8dR\xcdP\x81\xb8:j\x8c\xd4@\xa3\xd4\xfdg\xed\x0c5\xb9\x02^;\x88\x80\xbf\xa9ry\xf8\xae<\xf3\xf8i\xdc\x18\xe6\xea\xb9\x8a\xefCK\xa0\xcaU\x82\xc7\x0f\xdd'
        b'\x8bV\xc9\xaaF$oz\x19\xac\xec\xdb)x\xf5nO\x01h\xbb\xf1C@\x85s\xae\x18\xff\x03\xcb\xc8\x84\xb7=\xad\x11gl 6\xa8\xb5\x01@\x81dy\x07uu\x15\xf1U\x81K\xc0C?|\xd6\x1b\x83\x14\xea'
        b'\xda\x12\x12\x91\xe1\xd4\xa6u\x1a\xae>3\x8855\xda3\x9c\x0b\xed\xb5\x86^\xc1\xe8\xa7o\t \xda\x8a\xa8\x99\x87\xb3D\xed\xd9\x82\xa0#l\xc1\x9d\xee,|\xbf\x9dG\xd3M\x9b\x98\xd2I\xed\xeb\xdd\xf55UW\x1f'
        b"\xe8O\xeb[B\xf4\x1b\x80R[\xa8\xd8;\xa4\xac\xed\x01iJ\xbe\xdd\x1b\x9ew'\xac\x0b\xe9#$\xce\x04\xcf\xcb\xd5\xf9_\xa7\x04\x16`\xc4\xd1C\x1e\xb4\xa0x&b\x92+\x9b\xca\xc7\t\xf5\x07\xcd\xf6\x1flM\x88"
        b'M\xcc?\x80T7\xf8\xc1\xa8\xf2!\xd5\xf4\xbd\x83\xa1\xc2\x18\t\xe1\x12m\xfa\x8eE\xf8\x0f<@\x94\xa8x\x07\xbd)F.\xd1\xa6\x02Id\xa4`s\t\xcb\x82\x0c%\xafjY\x12\xc64_\xf5\x18\xb9\xa0+z/'
        b'\xfaK\xc7\xf9\x8fM\x17B\xd9\xf8HZyw_\xfc\xc5\xac\xe4\xe2\xcf\xb5=\xf38l\x0eJa\xfd[\x82\x0e\xd3Y\xe5yr\xac\x8fWi\xa9\x9f\x81b\x970\xc5\xf7;y\xb4\x86\x02\x8c\xb6\xed%\xd9;\x13\xdc\x87'
        b"\x9eU\x7f\x10P\xb3\x8eiW\xf61\xa2\xa1\xcbax\xef5\xe5>;\xde\xfb\x8f\xff0J}x7\x11C6\xb8J\xbd+\xf7\xb0\xa9\xe5G\x8f\x9b\xe9_\xd2'\xaaP\x85`\xf1g\x8fG8\x06\n\x9d9K\xb9\xbb"
        b'{\xed\x86\xcf\x95\xa9y:q\xe5\xee\x9bY\xacx_4\xd0\xe2\xd7\xae\x04\xc14q1F$\x86)hY\x10\x0b\x91dz\x87\x0e\x8aj]<\xc0\xf0\xb1:s\x86!&\xe6\xa5\xed\xcf\x1b{\x82\xec\xec\xf9\x95\xc3w'
        b"\x0b@&U/\xec\x04\xd5Qc\x18\xebRn\x99[%\xbb\x95\x07\x81\x07\xacDs\xf3l\xa6\x1fSI\x94(\xfci\xa0\x16\xe7\xa9^v\xae\xc6\x15\x82l[\x9bv\xb7\xb3\x8dj\xf5'8P\xda*\xf3%i\x9f\n"
        b'\x19\xf6\x84\xaa\xc5\xdf\xfa\xc5tl\xf7\x90\xfc9\x0f\xd0z>^w,\xd7#x\xb1\xde\x97\xb6\xfd\x9a\x8b4n\xe2BC\xbcw\xb7\xed\x12\x0e\x04O\r\x15$~\xed\xc8\xa9\xfa{\xce\x85\xb0\x1c\xc4"\xec\xd9D\xd4@'
        b'\xbe2\xf8\xf1\xcf\xbe\xb7F\x93\xc3\x02^\xa7\x8d\x0e\x906\xfaJI\xcf\x16\xdakx:\xea\xfd\xde\xc7\xb8\x05\x95,\xf3\xab\xef\xd8\x0e\xe8d\xc7\xe6\xe3AX\xe7\x08\xba\x8e\x92\xb0W\x04\x1e\xc9\xe30!\x04>\xcbW\xaa'
        b'\xbc\xe23\x82DrX\xa7\xca\x05\xbc5\xc2\x15\x1f\xb0\xa0i\x87\xf2~\xb1L\x84\x92_v\x16#\xd6W\xe1\x8a\xbc\x90y\xa4\xdcy\xcb\xb5\x17\x94RO\xdf\xda/!+\xba\xcd\x9c\x86\xd7\xd9#\xcb\x0f\xc4\xf8\xa7Pw'
        b'&\x06\xfc\xa9u\x02\xa8\xa7G)\xdd\x95\xb7\xa0c\x8dk\xb8x\xea\xe3\xfeK\x99\x14\xc3by\rL8!\x82O2\x03\xa6G>\x92)oJ\xae\x1b\x02\x1b|\xc1\x7f\x8d\x9e\xdf\xd3#\x86Eb[O\x16:`R'
        b'7\x99\x17\xd7;-\xa5\xfd\xc9g\xb6Dqe\x13\x02U\xd5\x02\xa9\xba\xbb\x87\xbf}\x87\xdb\x85\xf9{]x&xT\xd28R8\x13<\xa8\xaf\xe2[\xff\x8c] \xcb\xf0\xd8\x80\x02\xb1\xc8Q\x92GY!\x1a\xe7G'
        b'\x8c\x02\xad\xc7\x95\xfbG^Fp\x81\xc1r\x0eD\xfao:*\x01\xbd\x89\x17\xc0\xb4G\x86\x02\xb5\xe8%HtI\xd8\xc9\xa2s<Q\x1c\x1f\xf8\xcae\x8b(\xb7zE\x98\x9e\xa9\xc2\xf3\xb3_MT\xb83{\xef!'
        b'\xd7\x9c\xb4$\xa5\xf7 \x1e5\xc4\x16]\x0e\xbez\xbc\xa3\xab\xd9m|\x8a\xda6\x95\xa2@\xba\xd7\x84lU\xdbM\xad\xf9\x19R\r.\x89\xfey\xe3d4\x1c)KWi\x17\x8b\x8c\xa0S\x02 \xeb\x9b\x00\xaa[\xe7'
        b'\xf7V\xbc9\xbckK\x01\xa5.v\xd6\xff}\x1dY\xefSG\xf4r\xf7\xce\x9as\xb2Em\xca\xdcbk^\x81\x0c\xd8\xc9\x1ekv~\x9b\x00=\xb4\xd2y\x81[\x15n\xbd\x12\xe7#\x9c\x02\xcf$\x0f]\x12\xb6\x91'
        b'H\x15\xb89\xbf\x80Z\x87o\x9f\\\x98\xad\xb8\xc4\xe0\x93\x03\x9c\xcc\xd3\x04\x9a\xf1\xc9\xb6#\xe6\xb8U\xb1\xc5\xcc\xeb\xb7\xc8Ro\x16\xa3\x96\x9eL\x8d\xfd\xd7\xc1O\x08\x99)B\xb1!f\xc1A?\xd4\x08\xadW\xb59'
        b"\xf5\\\xf1\x0c\x92ij\xb3\x8164\xe0*\xbb\xc1w\xc2'1\x84\xe9+Qd\xf2\xf5\xd2\x8cV\x96.\x11\xe1\x89\xfc(\xbb\xde\xef\x7f\xcc\xd0A_\xc4\xb5\xe1\xb1\xb3-\xf1i\xd5qS\xe8\x87\x81\xd2\xfaX\xbd\x13\xa3"
        b'\xd2*\xa8\xaa\x19v8\x03&*\xf3\xa6Pr\x078\x95.)\xca7\x83!I\x8b\x95"\xbb\x8a\xae\xc7\xeeZ\x8c\x848\xc5\x98\xe8C9s\xd3\\?`\x99\x7f\xa4\x01hjV\xb2\xe2<\x13Z3\x03\xfe\xc0\xca\xca'
        b"\xc5Mc\x8e\x14*.\xf5\x10\x0f.\xc1m,1b\xf1\x94'D\xcd\xa8-\xfe\x0f[\xfa\x0e\x94\x1f\x94\x84\xf6\xd5\xa1\x0b\xae\x04\xdb\x19\x8c_Q-\x81\xc1Q\xe7\xca\x80J\xb9\xe95\x99\xaf\xdf\x84\xe0t0dM$"
        b"_.\xbcU\xa28$\xe7\xb7\xa7\xf2\x9bU\xe6~eB{\xbf\x9f\x16~Wp\xf33\xa7u\xdcY'f\xe5\x193\xc7\xd5\xa5\xcb\xab\xd7\x17K\\\x12\xe5!\xd4\x1c@_\xb0\rn\xf7\xe3r9e\xc9\xa4oS\xf1"
        b'\xda\xe3\x7f\xe9j\xf8\x89FD\xf9\xc3\xa1m\xdf\xe1\x0c\x0c\xbc\xf0\x1a\xb8\x10\xe7\xd7\x18\xf5\x1d\x08SS\x19k\xd5\xe4\x0f\xb2\xa1\xdb\x8e\xbb\xa3\xb0\xd5\xef\xbf/:&s\xf6b\xa8\x84\xe9c\xe1\x15\xba\xe3|A\xd8\xd9\x12'
        b"\xfd\x8d\x9cp\xa1f;\xa7xD~F7\x12F\x9a'\x8e^\xff\x93'\xb7\x07xQt@oa\xfeouI\x83\xc7'N\x94\xfb_f!\xa7V\xb8^J\xc7I\xb2nd\x0b&\xe6\xd8\xec\xab.\xb1\xd1\x1e\xeb"
        b'\xb4,E\x80\xb6\xcc\xe0\x0b\x1c\xff\x13\x81Q\xda\xf9nU\xe4\xb5&A\x17\x109\xe7s\xe6\xda\x88\xc9\xa2G(mn\n&\x8e])>\xb29\xfb-I\r\x89\x8a\x98\x89\\\x8dF\xf8\x06\xb4\xea\n\x86w\xc5\xd4w'
        b'#\x89\xdb\x87\xa5\xbd\xe4\x91\x93`i\xd4\xf0O<o\xb6\xf6\x94\xab-\xa2\xdaH\x82\xd1LR\xcbP\rl\x93j15\xd8\x8f"E\x16D\xee7\xae\xa3:\xa6\xc3 \xfa\xc6%\xa5\xd0gJ\x89vYJ\xf2\xdd\x97'
        b'\x91\x8d\xb6o,\x08X\xf7\x97\xff\x97UvC\xd2\xf1\xd429\xf2\xc05\xc2L"\xfd\x1f\x10\x142sX-\xe8\xaa\x92\x19\xf3\x1ax\xda\xd2[:Dt29ES\x18\xc4\xc0\xe7\xb3\x07H\x91\x9c\xaa{\xb02\\'
        b'w\xf3\xe05\x81\xd2\x7f\xc7\xa8\xf1\x81R\xfc( \xa9\xb4\xe6\xc9\xa7\x17A\x987\xa3\xf5\x80p\xfc\xb0gd\x8bh\xe9\xe3\xdc\x1b\xa2F_ZbY\x07\x0f,\x10\xff\x9b\x9eK\xfbA\xa6\xce\x17V0Y\x14\xc0\xd6\xd7'
        b'S\x19WS\x91\x05\x9fj?Q\xa2\x08^w\xb5\xb5@|Et\xda\xa7\x7f@\xdd\rB\xbc7 \xb5@\xf1\x83\xe8ijN\xcb.\x1f\x0e\xaa=Z\xb3\xb8\x07\xe5:\x84F.\xd1\xc7-\x1a\x06\xf9\x19\x02\xf9X\xd0'
        b'\x19\x8a\xa81\xad"\xdc\xd6c<V\xa3\xebT\x1e\x8bnr^-0LB\xde>\x95\x11\xfcT\x0c\xd8\x8d-\x1f\xe5^\xef#\xd6J~\x1f%"\xbf\\\x83\x95\x8a\xb6\x9a\x9e\xf2\xc0!lw\xfcz8\xa7U.\xa4'
        b'\xeb#\xdf=/$\xe6\x025\xe1\x10t\xd1&\x8b\x93\x9e\x8a\xb4%>\xe1"\x1e\xd6vp[\xcc@\t\xed\x15\xd7\x1cg\xf9*\xe3h&h\xb3\xe8b\xbf\xd8\xf9\x84\xd1\xd7?k\xa6\x8e*T\x8eM;7H|$'
        b')\xfcbw\xa9\xe0\xa1w\xa6\x1d\x99\xb5\x8b \x9f1r\x1f\x9dxe2\x1e\x86&JC\x16\xd9\x19\xaa\x81\x03i\xa0/\xfdy\xf5\xe5\x16S,YJ\x86[;\xdaH\x1c\xb2\x18\x19\x89~\x18v\x95\x9aV\xc7\xfc\xca'
        b'O\xddd\xc4\xb0\x89[O\xb1\x87\x08@A\x08\xcbS\xd7\xb8.f\x00#\x8e\xbe!\x05Hm\x10\xbb\xd4\x02\x86t\xb3wjF\xfd\xa1NH\xff*(\x08\xaba\x8c\x06\xe7Ah\x93\xdb\xa2\xbey\xb6ru\xf4\xf0\xbd'
        b'*\x87\x12\x95_\xb2\xdd\xfd:\x94\xb3\xda\t\xf8:\xf4\xf4A\xcc\xfch\x85\xe94[V\xab\x00\xeb\x93@\x9d}\x8b\x81\xd2\xaa@\x85\xb2X\xac\xf3fc\x03\xb1c\x98-\x13\xaa\xde\xc1\xf5\x99\xef\xc5\x9c/N\xda\x1b\xf0'
        b'=\xff\x11\x18\x03\xd1\xb2\x93\x11bB\xc7h\x1a\xe2\x85\xb4\xa8\x02\xf3\x1d=n\x93W\x95\x01O\xc9A\x92\xbf1\xfc6\xbf\x8c(\x18\x8b\xf0A\xbe0\xa6U\xda\x94}<>\xc2\xcd5`K(\xdf&v\x9fw.\x05'
        b'\x89\xd01rO\x8ej\xef.6U6\x930\x84\xfd<\x15\xfd\xccj\xa1\x91\xb2T\x0c\x8a\xf4D\x8e\x1d\x9e\xcd\x8d\x94\xcc\xae\xab\x1f\xb8\x0eZ\xbb\x95\xa7/z\x94\x92\x96\x8di\xec>iiM\xb7x\x81SAE\xfc'
        b'f\x8e\x90\xa4\xd75\x9b\xe81sl4Z~I\xec\xce\x80\t\xcc8D\t\x16\x9d\x8d\xb1\x7f\x18P\x9e;\xa7\xce!\xc1\x93\x00\x12\x14\xd9y\xea0r+\xb3m\xd2\xc2\xe3B0\x97w\xb4\x1b\xa5\xf6*\xf3\xdfl\x18'
        b"\xd4p\xdf\x83\x83\x9e\xaf'\x05Zq\xbc\x98Q\xab\x06A\x997\x83\xfb)e\xbbM\xa7\xafO\xe2,\xcc\xb9\xa4,C\xe4\xd4\xc8\x9d2E\x9d\xf4Q\xbf\xd16\x10_\xcf'!z]\xfa\xdc\xac\x88\x18A+\xc3\x18\xe6"
        b'\x06\x91/\x16\x1f)\x88\n\x81\xc0\x85\xfc\x00\x0e\xea\xb8\xda\xad\xbc\x17\xe9\x8fB\x17&\x19\xa8\xa2\xd7\xfap>|\x81\x18\x90EG\x8dv\xc4\r&V\xd4\xd0(s\tq\x8a\xd5~\xfa8\xb66\x17\x0c&\xd3\xa1WT'
        b'\xabv\xe5\xe9/\x08\xd4\x08\xf8\x99\xfb\xd3{\xfa\x0b\xe1\xbd\x07\xe2\xb5\xebC[\xd4w+\xff\x8b\xdb\x8d\xb8N\x8a \x04\x0e\xa8<\xc3\xe5\x95\x1d\xe6\xad7q\xbe\x891\r]L\x11\xc2^h\xed\xcf\x8f\x08\x03>+\x8c'
        b'\xf1l\xb1+\x13\x96wCg\xaa\x14[W~\x8e\x13\x99\x94|\xb2u.\x7f\xfdN\xfeo)\xa8\x06\x0b\xf6\x8c\xc7\x1b\xca\xd5\xb6\xed"\xae\xc4\xec\\|\xb3\xe2\x06)\x7fMc\x18\xacy^\xbd\x11\x16\xd4\n2G\xa4'
        b'\x06y\xd8q}e!\x83\x02\x0cXm3T\xf5\xdc\xacOHkH5\xe5\xf1\xe8:\x02\xe9\xd1\x9a\xe7\x03Jt\x93\xdb\xb5&\x1d\x05H\xaeD\xcdT\xa6\xe2\x8b\xbb5\x85/_\x0e\x86,)\xce\x06\x1fQ\xa3S@'
        b"\x8a\xe0i\xa6\xd7\xc7:\xc8'\xae\xe9\x1d\x8d\x01\xf1%\xb3\x8c\xd5\x98a\xb2\xa3\xf7}kG/c\xd7\xcd\xab!\xf4\xf6-\xa9}\r\xda\xe5ia(0\x1e\xf8\x95\xc6\xfb]a\xa3(\x10S\xef\x1d\x1bT*pz\xd4"
        b"^\xc1\x0c4\x18\xe8\xe5\x07\xe7\xf7\xc9'FF\xc0\x1cn\xcb\x14n\x8e\x87\x94\x9b\x8c\xe1X\x14\x0b\x82>\xad~\r\xfe8&\xff\xfe~1!\xc1\xff|b\xd8\xe3\xe8\x1e&\x1b\xa8\xde'\xab\xb9\xc0\x9b\x1c\xc5\xca\xcc\x8c"
        b'F\xe3\xf0\xdb)\xeb\xdb\x0f\xa3\x9f&\xd0\xfd\x8d\r;\xed?.\n\x9d\xd1 J\x13]\x91\xdd\xa1\xb8\xac\xf2\xa1O\xdb=h\xeb\xe5\xcbl&D9e\xb8\x1d\xc9#\xb6yd\xae\xf6\t+]y\xbc\x80\xbe\x08\xd6N'
        b"B\x17\xb1\xb0JO*\x14\xe9X\xf0'\xa9\xce\xb6\xc7\x10\x19\xd5\xc4q[\xae\x83\xc1\xda\x8d\t\x83\xfb\xefD\x04#4 \x1e\xa4\x94t{\x99\xbb\xc3B\xc7\xb5\xcbEO*\x9fz\x17\x9e0\x8d'zUUov\xa0"
        b'(\x85ZQ\x18\xe8D\xedF\xbdc\t.\x0f\x0c \x1e\xba\x9e\xdc\xbb0\xb4\x81%T\x10\x17\xc3\x8ef\x85\xca\xc5a\xc5\x97^\xab5\x89\x007\xa5\xe9\x89\xd6\xbb\x86\xd88\xe4\xf1\nNi\x8a\xe6s\xb3\xb1x\xb9\xe0'
        b"U'c_Q|\xb2\x17`#]$\xe4s\xfd{\xac\xa0\xb8\x8a9\xefx\x1c\xfe!\xef\x17\x0b\x1b\x1fH\xb4\x16}\x08\xce\xe7,[\r\x1e\xb2\xd3\xaa\xadna\xa2\xdc\xb4\t\xabiY\x02\xd7\x05XG\x89\x9a\xd0\xcb"
        b"'\x8aB\xead?v\xc0\x97\tR\xc9\xb5\xef\xe7\x92z6u\x03U\xa8\xd7\xdf\xfb\xf1\x0b\x04\x97\xc4\xe7*\xca\xfb\n\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntim"
        b'eError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08'
        b'<module>\x01\x00\x00\x00s\x04\x00\x00\x00\n\x01\x14\x01'
    ))
